/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtBluetoothAPI_H
#define _QtBluetoothAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_Vulkan
#define SIP_FEATURE_PyQt_Wayland
#define SIP_FEATURE_PyQt_XCB
#define SIP_FEATURE_PyQt_Permissions
#define SIP_FEATURE_PyQt_DTLS
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_OpenGL_ES2
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_Linux
#define SIP_TIMELINE_Qt_6_11_0


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_0 0
#define sipName_0 &sipStrings_QtBluetooth[0]
#define sipNameNr_56 56
#define sipName_56 &sipStrings_QtBluetooth[56]
#define sipNameNr_QBluetoothDeviceDiscoveryAgent__DiscoveryMethod 108
#define sipName_QBluetoothDeviceDiscoveryAgent__DiscoveryMethod &sipStrings_QtBluetooth[108]
#define sipNameNr_156 156
#define sipName_156 &sipStrings_QtBluetooth[156]
#define sipNameNr_QBluetoothServiceDiscoveryAgent__DiscoveryMode 204
#define sipName_QBluetoothServiceDiscoveryAgent__DiscoveryMode &sipStrings_QtBluetooth[204]
#define sipNameNr_251 251
#define sipName_251 &sipStrings_QtBluetooth[251]
#define sipNameNr_IEEE1107320601RegulatoryCertificationDataList 298
#define sipName_IEEE1107320601RegulatoryCertificationDataList &sipStrings_QtBluetooth[298]
#define sipNameNr_QBluetoothDeviceInfo__MinorMiscellaneousClass 344
#define sipName_QBluetoothDeviceInfo__MinorMiscellaneousClass &sipStrings_QtBluetooth[344]
#define sipNameNr_QLowEnergyAdvertisingParameters__FilterPolicy 390
#define sipName_QLowEnergyAdvertisingParameters__FilterPolicy &sipStrings_QtBluetooth[390]
#define sipNameNr_QLowEnergyAdvertisingParameters__AddressInfo 436
#define sipName_QLowEnergyAdvertisingParameters__AddressInfo &sipStrings_QtBluetooth[436]
#define sipNameNr_QBluetoothDeviceInfo__MinorAudioVideoClass 481
#define sipName_QBluetoothDeviceInfo__MinorAudioVideoClass &sipStrings_QtBluetooth[481]
#define sipNameNr_QBluetoothDeviceInfo__MinorPeripheralClass 524
#define sipName_QBluetoothDeviceInfo__MinorPeripheralClass &sipStrings_QtBluetooth[524]
#define sipNameNr_567 567
#define sipName_567 &sipStrings_QtBluetooth[567]
#define sipNameNr_QLowEnergyAdvertisingData__Discoverability 610
#define sipName_QLowEnergyAdvertisingData__Discoverability &sipStrings_QtBluetooth[610]
#define sipNameNr_QBluetoothDeviceInfo__MinorComputerClass 653
#define sipName_QBluetoothDeviceInfo__MinorComputerClass &sipStrings_QtBluetooth[653]
#define sipNameNr_QBluetoothDeviceInfo__MinorWearableClass 694
#define sipName_QBluetoothDeviceInfo__MinorWearableClass &sipStrings_QtBluetooth[694]
#define sipNameNr_PeripheralPreferredConnectionParameters 735
#define sipName_PeripheralPreferredConnectionParameters &sipStrings_QtBluetooth[735]
#define sipNameNr_QBluetoothDeviceInfo__CoreConfiguration 775
#define sipName_QBluetoothDeviceInfo__CoreConfiguration &sipStrings_QtBluetooth[775]
#define sipNameNr_QBluetoothDeviceInfo__MinorImagingClass 815
#define sipName_QBluetoothDeviceInfo__MinorImagingClass &sipStrings_QtBluetooth[815]
#define sipNameNr_QBluetoothDeviceInfo__MinorNetworkClass 855
#define sipName_QBluetoothDeviceInfo__MinorNetworkClass &sipStrings_QtBluetooth[855]
#define sipNameNr_895 895
#define sipName_895 &sipStrings_QtBluetooth[895]
#define sipNameNr_QLowEnergyController__RemoteAddressType 935
#define sipName_QLowEnergyController__RemoteAddressType &sipStrings_QtBluetooth[935]
#define sipNameNr_QBluetoothDeviceInfo__MajorDeviceClass 975
#define sipName_QBluetoothDeviceInfo__MajorDeviceClass &sipStrings_QtBluetooth[975]
#define sipNameNr_QBluetoothDeviceInfo__MinorHealthClass 1014
#define sipName_QBluetoothDeviceInfo__MinorHealthClass &sipStrings_QtBluetooth[1014]
#define sipNameNr_QBluetoothServiceDiscoveryAgent__Error 1053
#define sipName_QBluetoothServiceDiscoveryAgent__Error &sipStrings_QtBluetooth[1053]
#define sipNameNr_1092 1092
#define sipName_1092 &sipStrings_QtBluetooth[1092]
#define sipNameNr_QLowEnergyCharacteristic__PropertyType 1131
#define sipName_QLowEnergyCharacteristic__PropertyType &sipStrings_QtBluetooth[1131]
#define sipNameNr_SportTypeForAerobicAnaerobicThresholds 1170
#define sipName_SportTypeForAerobicAnaerobicThresholds &sipStrings_QtBluetooth[1170]
#define sipNameNr_BaseRateAndLowEnergyCoreConfiguration 1209
#define sipName_BaseRateAndLowEnergyCoreConfiguration &sipStrings_QtBluetooth[1209]
#define sipNameNr_DirectPrintingReferenceObjectsService 1247
#define sipName_DirectPrintingReferenceObjectsService &sipStrings_QtBluetooth[1247]
#define sipNameNr_QBluetoothDeviceDiscoveryAgent__Error 1285
#define sipName_QBluetoothDeviceDiscoveryAgent__Error &sipStrings_QtBluetooth[1285]
#define sipNameNr_QBluetoothDeviceInfo__MinorPhoneClass 1323
#define sipName_QBluetoothDeviceInfo__MinorPhoneClass &sipStrings_QtBluetooth[1323]
#define sipNameNr_QLowEnergyAdvertisingParameters__Mode 1361
#define sipName_QLowEnergyAdvertisingParameters__Mode &sipStrings_QtBluetooth[1361]
#define sipNameNr_QLowEnergyController__ControllerState 1399
#define sipName_QLowEnergyController__ControllerState &sipStrings_QtBluetooth[1399]
#define sipNameNr_1437 1437
#define sipName_1437 &sipStrings_QtBluetooth[1437]
#define sipNameNr_KeyboardWithPointingDevicePeripheral 1475
#define sipName_KeyboardWithPointingDevicePeripheral &sipStrings_QtBluetooth[1475]
#define sipNameNr_UseWhiteListForScanningAndConnecting 1512
#define sipName_UseWhiteListForScanningAndConnecting &sipStrings_QtBluetooth[1512]
#define sipNameNr_QBluetoothDeviceInfo__MinorToyClass 1549
#define sipName_QBluetoothDeviceInfo__MinorToyClass &sipStrings_QtBluetooth[1549]
#define sipNameNr_1585 1585
#define sipName_1585 &sipStrings_QtBluetooth[1585]
#define sipNameNr_1621 1621
#define sipName_1621 &sipStrings_QtBluetooth[1621]
#define sipNameNr_EnvironmentalSensingTriggerSetting 1657
#define sipName_EnvironmentalSensingTriggerSetting &sipStrings_QtBluetooth[1657]
#define sipNameNr_QBluetoothDeviceInfo__ServiceClass 1692
#define sipName_QBluetoothDeviceInfo__ServiceClass &sipStrings_QtBluetooth[1692]
#define sipNameNr_QBluetoothServiceInfo__AttributeId 1727
#define sipName_QBluetoothServiceInfo__AttributeId &sipStrings_QtBluetooth[1727]
#define sipNameNr_QBluetoothUuid__CharacteristicType 1762
#define sipName_QBluetoothUuid__CharacteristicType &sipStrings_QtBluetooth[1762]
#define sipNameNr_QLowEnergyServiceData__ServiceType 1797
#define sipName_QLowEnergyServiceData__ServiceType &sipStrings_QtBluetooth[1797]
#define sipNameNr_ClientCharacteristicConfiguration 1832
#define sipName_ClientCharacteristicConfiguration &sipStrings_QtBluetooth[1832]
#define sipNameNr_EnvironmentalSensingConfiguration 1866
#define sipName_EnvironmentalSensingConfiguration &sipStrings_QtBluetooth[1866]
#define sipNameNr_ServerCharacteristicConfiguration 1900
#define sipName_ServerCharacteristicConfiguration &sipStrings_QtBluetooth[1900]
#define sipNameNr_clientCharacteristicConfiguration 1934
#define sipName_clientCharacteristicConfiguration &sipStrings_QtBluetooth[1934]
#define sipNameNr_AdditionalProtocolDescriptorList 1968
#define sipName_AdditionalProtocolDescriptorList &sipStrings_QtBluetooth[1968]
#define sipNameNr_CharacteristicExtendedProperties 2001
#define sipName_CharacteristicExtendedProperties &sipStrings_QtBluetooth[2001]
#define sipNameNr_CharacteristicPresentationFormat 2034
#define sipName_CharacteristicPresentationFormat &sipStrings_QtBluetooth[2034]
#define sipNameNr_QBluetoothUuid__ServiceClassUuid 2067
#define sipName_QBluetoothUuid__ServiceClassUuid &sipStrings_QtBluetooth[2067]
#define sipNameNr_QLowEnergyService__DiscoveryMode 2100
#define sipName_QLowEnergyService__DiscoveryMode &sipStrings_QtBluetooth[2100]
#define sipNameNr_EnvironmentalSensingMeasurement 2133
#define sipName_EnvironmentalSensingMeasurement &sipStrings_QtBluetooth[2133]
#define sipNameNr_QBluetooth__AttAccessConstraint 2165
#define sipName_QBluetooth__AttAccessConstraint &sipStrings_QtBluetooth[2165]
#define sipNameNr_QBluetoothLocalDevice__HostMode 2197
#define sipName_QBluetoothLocalDevice__HostMode &sipStrings_QtBluetooth[2197]
#define sipNameNr_QBluetoothServiceDiscoveryAgent 2229
#define sipName_QBluetoothServiceDiscoveryAgent &sipStrings_QtBluetooth[2229]
#define sipNameNr_QBluetoothServiceInfo__Protocol 2261
#define sipName_QBluetoothServiceInfo__Protocol &sipStrings_QtBluetooth[2261]
#define sipNameNr_QBluetoothServiceInfo__Sequence 2293
#define sipName_QBluetoothServiceInfo__Sequence &sipStrings_QtBluetooth[2293]
#define sipNameNr_2325 2325
#define sipName_2325 &sipStrings_QtBluetooth[2325]
#define sipNameNr_2357 2357
#define sipName_2357 &sipStrings_QtBluetooth[2357]
#define sipNameNr_QLowEnergyAdvertisingParameters 2389
#define sipName_QLowEnergyAdvertisingParameters &sipStrings_QtBluetooth[2389]
#define sipNameNr_QLowEnergyService__ServiceError 2421
#define sipName_QLowEnergyService__ServiceError &sipStrings_QtBluetooth[2421]
#define sipNameNr_QLowEnergyService__ServiceState 2453
#define sipName_QLowEnergyService__ServiceState &sipStrings_QtBluetooth[2453]
#define sipNameNr_BluetoothProfileDescriptorList 2485
#define sipName_BluetoothProfileDescriptorList &sipStrings_QtBluetooth[2485]
#define sipNameNr_HostDiscoverableLimitedInquiry 2516
#define sipName_HostDiscoverableLimitedInquiry &sipStrings_QtBluetooth[2516]
#define sipNameNr_QBluetoothDeviceDiscoveryAgent 2547
#define sipName_QBluetoothDeviceDiscoveryAgent &sipStrings_QtBluetooth[2547]
#define sipNameNr_QBluetoothLocalDevice__Pairing 2578
#define sipName_QBluetoothLocalDevice__Pairing &sipStrings_QtBluetooth[2578]
#define sipNameNr_QBluetoothUuid__DescriptorType 2609
#define sipName_QBluetoothUuid__DescriptorType &sipStrings_QtBluetooth[2609]
#define sipNameNr_QLowEnergyConnectionParameters 2640
#define sipName_QLowEnergyConnectionParameters &sipStrings_QtBluetooth[2640]
#define sipNameNr_QLowEnergyService__ServiceType 2671
#define sipName_QLowEnergyService__ServiceType &sipStrings_QtBluetooth[2671]
#define sipNameNr_2702 2702
#define sipName_2702 &sipStrings_QtBluetooth[2702]
#define sipNameNr_AlertNotificationControlPoint 2733
#define sipName_AlertNotificationControlPoint &sipStrings_QtBluetooth[2733]
#define sipNameNr_CharacteristicAggregateFormat 2763
#define sipName_CharacteristicAggregateFormat &sipStrings_QtBluetooth[2763]
#define sipNameNr_CharacteristicUserDescription 2793
#define sipName_CharacteristicUserDescription &sipStrings_QtBluetooth[2793]
#define sipNameNr_LocationServiceTurnedOffError 2823
#define sipName_LocationServiceTurnedOffError &sipStrings_QtBluetooth[2823]
#define sipNameNr_QBluetoothSocket__SocketError 2853
#define sipName_QBluetoothSocket__SocketError &sipStrings_QtBluetooth[2853]
#define sipNameNr_QBluetoothSocket__SocketState 2883
#define sipName_QBluetoothSocket__SocketState &sipStrings_QtBluetooth[2883]
#define sipNameNr_ServiceAlreadyRegisteredError 2913
#define sipName_ServiceAlreadyRegisteredError &sipStrings_QtBluetooth[2913]
#define sipNameNr_UncategorizedAudioVideoDevice 2943
#define sipName_UncategorizedAudioVideoDevice &sipStrings_QtBluetooth[2943]
#define sipNameNr_WiredModemOrVoiceGatewayPhone 2973
#define sipName_WiredModemOrVoiceGatewayPhone &sipStrings_QtBluetooth[2973]
#define sipNameNr_AnaerobicHeartRateLowerLimit 3003
#define sipName_AnaerobicHeartRateLowerLimit &sipStrings_QtBluetooth[3003]
#define sipNameNr_AnaerobicHeartRateUpperLimit 3032
#define sipName_AnaerobicHeartRateUpperLimit &sipStrings_QtBluetooth[3032]
#define sipNameNr_InvalidBluetoothAdapterError 3061
#define sipName_InvalidBluetoothAdapterError &sipStrings_QtBluetooth[3061]
#define sipNameNr_QBluetoothLocalDevice__Error 3090
#define sipName_QBluetoothLocalDevice__Error &sipStrings_QtBluetooth[3090]
#define sipNameNr_QBluetoothUuid__ProtocolUuid 3119
#define sipName_QBluetoothUuid__ProtocolUuid &sipStrings_QtBluetooth[3119]
#define sipNameNr_3148 3148
#define sipName_3148 &sipStrings_QtBluetooth[3148]
#define sipNameNr_3177 3177
#define sipName_3177 &sipStrings_QtBluetooth[3177]
#define sipNameNr_QLowEnergyCharacteristicData 3206
#define sipName_QLowEnergyCharacteristicData &sipStrings_QtBluetooth[3206]
#define sipNameNr_QLowEnergyService__WriteMode 3235
#define sipName_QLowEnergyService__WriteMode &sipStrings_QtBluetooth[3235]
#define sipNameNr_SupportedUnreadAlertCategory 3264
#define sipName_SupportedUnreadAlertCategory &sipStrings_QtBluetooth[3264]
#define sipNameNr_setLowEnergyDiscoveryTimeout 3293
#define sipName_setLowEnergyDiscoveryTimeout &sipStrings_QtBluetooth[3293]
#define sipNameNr_ContinuousGlucoseMonitoring 3322
#define sipName_ContinuousGlucoseMonitoring &sipStrings_QtBluetooth[3322]
#define sipNameNr_HumanInterfaceDeviceService 3350
#define sipName_HumanInterfaceDeviceService &sipStrings_QtBluetooth[3350]
#define sipNameNr_LanguageBaseAttributeIdList 3378
#define sipName_LanguageBaseAttributeIdList &sipStrings_QtBluetooth[3378]
#define sipNameNr_MaximumRecommendedHeartRate 3406
#define sipName_MaximumRecommendedHeartRate &sipStrings_QtBluetooth[3406]
#define sipNameNr_QBluetoothDeviceInfo__Field 3434
#define sipName_QBluetoothDeviceInfo__Field &sipStrings_QtBluetooth[3434]
#define sipNameNr_3462 3462
#define sipName_3462 &sipStrings_QtBluetooth[3462]
#define sipNameNr_3490 3490
#define sipName_3490 &sipStrings_QtBluetooth[3490]
#define sipNameNr_QLowEnergyController__Error 3518
#define sipName_QLowEnergyController__Error &sipStrings_QtBluetooth[3518]
#define sipNameNr_UncategorizedWearableDevice 3546
#define sipName_UncategorizedWearableDevice &sipStrings_QtBluetooth[3546]
#define sipNameNr_AV_RemoteControlController 3574
#define sipName_AV_RemoteControlController &sipStrings_QtBluetooth[3574]
#define sipNameNr_AerobicHeartRateLowerLimit 3601
#define sipName_AerobicHeartRateLowerLimit &sipStrings_QtBluetooth[3601]
#define sipNameNr_AerobicHeartRateUpperLimit 3628
#define sipName_AerobicHeartRateUpperLimit &sipStrings_QtBluetooth[3628]
#define sipNameNr_BodyCompositionMeasurement 3655
#define sipName_BodyCompositionMeasurement &sipStrings_QtBluetooth[3655]
#define sipNameNr_FatBurnHeartRateLowerLimit 3682
#define sipName_FatBurnHeartRateLowerLimit &sipStrings_QtBluetooth[3682]
#define sipNameNr_FatBurnHeartRateUpperLimit 3709
#define sipName_FatBurnHeartRateUpperLimit &sipStrings_QtBluetooth[3709]
#define sipNameNr_HealthBloodPressureMonitor 3736
#define sipName_HealthBloodPressureMonitor &sipStrings_QtBluetooth[3736]
#define sipNameNr_LowEnergyCoreConfiguration 1220
#define sipName_LowEnergyCoreConfiguration &sipStrings_QtBluetooth[1220]
#define sipNameNr_QLowEnergyController__Role 3763
#define sipName_QLowEnergyController__Role &sipStrings_QtBluetooth[3763]
#define sipNameNr_ReferenceTimeUpdateService 3790
#define sipName_ReferenceTimeUpdateService &sipStrings_QtBluetooth[3790]
#define sipNameNr_UncategorizedImagingDevice 3817
#define sipName_UncategorizedImagingDevice &sipStrings_QtBluetooth[3817]
#define sipNameNr_UncategorizedMiscellaneous 3844
#define sipName_UncategorizedMiscellaneous &sipStrings_QtBluetooth[3844]
#define sipNameNr_UnsupportedDiscoveryMethod 3871
#define sipName_UnsupportedDiscoveryMethod &sipStrings_QtBluetooth[3871]
#define sipNameNr_VideoDisplayAndLoudspeaker 3898
#define sipName_VideoDisplayAndLoudspeaker &sipStrings_QtBluetooth[3898]
#define sipNameNr_protocolServiceMultiplexer 3925
#define sipName_protocolServiceMultiplexer &sipStrings_QtBluetooth[3925]
#define sipNameNr_AdvancedAudioDistribution 3952
#define sipName_AdvancedAudioDistribution &sipStrings_QtBluetooth[3952]
#define sipNameNr_AttAuthenticationRequired 3978
#define sipName_AttAuthenticationRequired &sipStrings_QtBluetooth[3978]
#define sipNameNr_BaseRateCoreConfiguration 4004
#define sipName_BaseRateCoreConfiguration &sipStrings_QtBluetooth[4004]
#define sipNameNr_DateOfThresholdAssessment 4030
#define sipName_DateOfThresholdAssessment &sipStrings_QtBluetooth[4030]
#define sipNameNr_DigitizerTabletPeripheral 4056
#define sipName_DigitizerTabletPeripheral &sipStrings_QtBluetooth[4056]
#define sipNameNr_GlucoseMeasurementContext 4082
#define sipName_GlucoseMeasurementContext &sipStrings_QtBluetooth[4082]
#define sipNameNr_HandheldClamShellComputer 4108
#define sipName_HandheldClamShellComputer &sipStrings_QtBluetooth[4108]
#define sipNameNr_MessageNotificationServer 4134
#define sipName_MessageNotificationServer &sipStrings_QtBluetooth[4134]
#define sipNameNr_4160 4160
#define sipName_4160 &sipStrings_QtBluetooth[4160]
#define sipNameNr_4186 4186
#define sipName_4186 &sipStrings_QtBluetooth[4186]
#define sipNameNr_QLowEnergyAdvertisingData 4212
#define sipName_QLowEnergyAdvertisingData &sipStrings_QtBluetooth[4212]
#define sipNameNr_SupportedNewAlertCategory 4238
#define sipName_SupportedNewAlertCategory &sipStrings_QtBluetooth[4238]
#define sipNameNr_UncategorizedHealthDevice 4264
#define sipName_UncategorizedHealthDevice &sipStrings_QtBluetooth[4264]
#define sipNameNr_UseWhiteListForConnecting 4290
#define sipName_UseWhiteListForConnecting &sipStrings_QtBluetooth[4290]
#define sipNameNr_lowEnergyDiscoveryTimeout 4316
#define sipName_lowEnergyDiscoveryTimeout &sipStrings_QtBluetooth[4316]
#define sipNameNr_setPreferredSecurityFlags 4342
#define sipName_setPreferredSecurityFlags &sipStrings_QtBluetooth[4342]
#define sipNameNr_supportedDiscoveryMethods 4368
#define sipName_supportedDiscoveryMethods &sipStrings_QtBluetooth[4368]
#define sipNameNr_AlertNotificationService 4394
#define sipName_AlertNotificationService &sipStrings_QtBluetooth[4394]
#define sipNameNr_AttAuthorizationRequired 4419
#define sipName_AttAuthorizationRequired &sipStrings_QtBluetooth[4419]
#define sipNameNr_BloodPressureMeasurement 4444
#define sipName_BloodPressureMeasurement &sipStrings_QtBluetooth[4444]
#define sipNameNr_BootKeyboardOutputReport 4469
#define sipName_BootKeyboardOutputReport &sipStrings_QtBluetooth[4469]
#define sipNameNr_CharacteristicWriteError 4494
#define sipName_CharacteristicWriteError &sipStrings_QtBluetooth[4494]
#define sipNameNr_CyclingPowerControlPoint 4519
#define sipName_CyclingPowerControlPoint &sipStrings_QtBluetooth[4519]
#define sipNameNr_HardcopyCableReplacement 4544
#define sipName_HardcopyCableReplacement &sipStrings_QtBluetooth[4544]
#define sipNameNr_IntermediateCuffPressure 4569
#define sipName_IntermediateCuffPressure &sipStrings_QtBluetooth[4569]
#define sipNameNr_PointingDevicePeripheral 1487
#define sipName_PointingDevicePeripheral &sipStrings_QtBluetooth[1487]
#define sipNameNr_4594 4594
#define sipName_4594 &sipStrings_QtBluetooth[4594]
#define sipNameNr_QLowEnergyCharacteristic 4619
#define sipName_QLowEnergyCharacteristic &sipStrings_QtBluetooth[4619]
#define sipNameNr_QLowEnergyDescriptorData 4644
#define sipName_QLowEnergyDescriptorData &sipStrings_QtBluetooth[4644]
#define sipNameNr_RecordAccessControlPoint 4669
#define sipName_RecordAccessControlPoint &sipStrings_QtBluetooth[4669]
#define sipNameNr_ReferenceTimeInformation 4694
#define sipName_ReferenceTimeInformation &sipStrings_QtBluetooth[4694]
#define sipNameNr_RemoteServiceDiscovering 4719
#define sipName_RemoteServiceDiscovering &sipStrings_QtBluetooth[4719]
#define sipNameNr_ThreeZoneHeartRateLimits 4744
#define sipName_ThreeZoneHeartRateLimits &sipStrings_QtBluetooth[4744]
#define sipNameNr_UnknownCoreConfiguration 4769
#define sipName_UnknownCoreConfiguration &sipStrings_QtBluetooth[4769]
#define sipNameNr_UnknownRemoteDeviceError 4794
#define sipName_UnknownRemoteDeviceError &sipStrings_QtBluetooth[4794]
#define sipNameNr_UnsupportedPlatformError 4819
#define sipName_UnsupportedPlatformError &sipStrings_QtBluetooth[4819]
#define sipNameNr_UnsupportedProtocolError 4844
#define sipName_UnsupportedProtocolError &sipStrings_QtBluetooth[4844]
#define sipNameNr_setMaxPendingConnections 4869
#define sipName_setMaxPendingConnections &sipStrings_QtBluetooth[4869]
#define sipNameNr_BarometricPressureTrend 4894
#define sipName_BarometricPressureTrend &sipStrings_QtBluetooth[4894]
#define sipNameNr_BootKeyboardInputReport 4918
#define sipName_BootKeyboardInputReport &sipStrings_QtBluetooth[4918]
#define sipNameNr_CharacteristicReadError 4942
#define sipName_CharacteristicReadError &sipStrings_QtBluetooth[4942]
#define sipNameNr_CyclingPowerMeasurement 4966
#define sipName_CyclingPowerMeasurement &sipStrings_QtBluetooth[4966]
#define sipNameNr_DatabaseChangeIncrement 4990
#define sipName_DatabaseChangeIncrement &sipStrings_QtBluetooth[4990]
#define sipNameNr_ExternalReportReference 5014
#define sipName_ExternalReportReference &sipStrings_QtBluetooth[5014]
#define sipNameNr_FiveZoneHeartRateLimits 5038
#define sipName_FiveZoneHeartRateLimits &sipStrings_QtBluetooth[5038]
#define sipNameNr_ImagingAutomaticArchive 5062
#define sipName_ImagingAutomaticArchive &sipStrings_QtBluetooth[5062]
#define sipNameNr_ImagingReferenceObjects 5086
#define sipName_ImagingReferenceObjects &sipStrings_QtBluetooth[5086]
#define sipNameNr_IntermediateTemperature 5110
#define sipName_IntermediateTemperature &sipStrings_QtBluetooth[5110]
#define sipNameNr_MinorMiscellaneousClass 366
#define sipName_MinorMiscellaneousClass &sipStrings_QtBluetooth[366]
#define sipNameNr_MissingPermissionsError 5134
#define sipName_MissingPermissionsError &sipStrings_QtBluetooth[5134]
#define sipNameNr_PhoneAlertStatusService 5158
#define sipName_PhoneAlertStatusService &sipStrings_QtBluetooth[5158]
#define sipNameNr_PyQt6_sip_simplewrapper 5182
#define sipName_PyQt6_sip_simplewrapper &sipStrings_QtBluetooth[5182]
#define sipNameNr_QBluetoothServer__Error 5206
#define sipName_QBluetoothServer__Error &sipStrings_QtBluetooth[5206]
#define sipNameNr_RemoteControlPeripheral 5230
#define sipName_RemoteControlPeripheral &sipStrings_QtBluetooth[5230]
#define sipNameNr_RemoteServiceDiscovered 5254
#define sipName_RemoteServiceDiscovered &sipStrings_QtBluetooth[5254]
#define sipNameNr_SensingDevicePeripheral 5278
#define sipName_SensingDevicePeripheral &sipStrings_QtBluetooth[5278]
#define sipNameNr_UncategorizedPeripheral 5302
#define sipName_UncategorizedPeripheral &sipStrings_QtBluetooth[5302]
#define sipNameNr_UseWhiteListForScanning 5326
#define sipName_UseWhiteListForScanning &sipStrings_QtBluetooth[5326]
#define sipNameNr_requestConnectionUpdate 5350
#define sipName_requestConnectionUpdate &sipStrings_QtBluetooth[5350]
#define sipNameNr_AV_RemoteControlTarget 5374
#define sipName_AV_RemoteControlTarget &sipStrings_QtBluetooth[5374]
#define sipNameNr_AlertCategoryIDBitMask 5397
#define sipName_AlertCategoryIDBitMask &sipStrings_QtBluetooth[5397]
#define sipNameNr_BodyCompositionFeature 5420
#define sipName_BodyCompositionFeature &sipStrings_QtBluetooth[5420]
#define sipNameNr_CCCDEnableNotification 5443
#define sipName_CCCDEnableNotification &sipStrings_QtBluetooth[5443]
#define sipNameNr_CyclingSpeedAndCadence 5466
#define sipName_CyclingSpeedAndCadence &sipStrings_QtBluetooth[5466]
#define sipNameNr_DescriptorValueChanged 5489
#define sipName_DescriptorValueChanged &sipStrings_QtBluetooth[5489]
#define sipNameNr_DiscoverabilityGeneral 5512
#define sipName_DiscoverabilityGeneral &sipStrings_QtBluetooth[5512]
#define sipNameNr_DiscoverabilityLimited 5535
#define sipName_DiscoverabilityLimited &sipStrings_QtBluetooth[5535]
#define sipNameNr_FirmwareRevisionString 5558
#define sipName_FirmwareRevisionString &sipStrings_QtBluetooth[5558]
#define sipNameNr_HardcopyControlChannel 5581
#define sipName_HardcopyControlChannel &sipStrings_QtBluetooth[5581]
#define sipNameNr_HardwareRevisionString 5604
#define sipName_HardwareRevisionString &sipStrings_QtBluetooth[5604]
#define sipNameNr_ManufacturerNameString 5627
#define sipName_ManufacturerNameString &sipStrings_QtBluetooth[5627]
#define sipNameNr_NetworkLoadFactorThree 5650
#define sipName_NetworkLoadFactorThree &sipStrings_QtBluetooth[5650]
#define sipNameNr_ProtocolDescriptorList 1978
#define sipName_ProtocolDescriptorList &sipStrings_QtBluetooth[1978]
#define sipNameNr_RunningSpeedAndCadence 5673
#define sipName_RunningSpeedAndCadence &sipStrings_QtBluetooth[5673]
#define sipNameNr_ServiceDiscoveryServer 5696
#define sipName_ServiceDiscoveryServer &sipStrings_QtBluetooth[5696]
#define sipNameNr_SoftwareRevisionString 5719
#define sipName_SoftwareRevisionString &sipStrings_QtBluetooth[5719]
#define sipNameNr_TemperatureMeasurement 5742
#define sipName_TemperatureMeasurement &sipStrings_QtBluetooth[5742]
#define sipNameNr_TimeUpdateControlPoint 5765
#define sipName_TimeUpdateControlPoint &sipStrings_QtBluetooth[5765]
#define sipNameNr_TwoZoneHeartRateLimits 5788
#define sipName_TwoZoneHeartRateLimits &sipStrings_QtBluetooth[5788]
#define sipNameNr_characteristicToString 5811
#define sipName_characteristicToString &sipStrings_QtBluetooth[5811]
#define sipNameNr_preferredSecurityFlags 5834
#define sipName_preferredSecurityFlags &sipStrings_QtBluetooth[5834]
#define sipNameNr_setServiceAvailability 5857
#define sipName_setServiceAvailability &sipStrings_QtBluetooth[5857]
#define sipNameNr_ApparentWindDirection 5880
#define sipName_ApparentWindDirection &sipStrings_QtBluetooth[5880]
#define sipNameNr_AttEncryptionRequired 5902
#define sipName_AttEncryptionRequired &sipStrings_QtBluetooth[5902]
#define sipNameNr_BrowseGroupDescriptor 5924
#define sipName_BrowseGroupDescriptor &sipStrings_QtBluetooth[5924]
#define sipNameNr_CommonIsdnAccessPhone 5946
#define sipName_CommonIsdnAccessPhone &sipStrings_QtBluetooth[5946]
#define sipNameNr_HandsfreeAudioGateway 5968
#define sipName_HandsfreeAudioGateway &sipStrings_QtBluetooth[5968]
#define sipNameNr_HeartRateControlPoint 5990
#define sipName_HeartRateControlPoint &sipStrings_QtBluetooth[5990]
#define sipNameNr_LocationAndNavigation 6012
#define sipName_LocationAndNavigation &sipStrings_QtBluetooth[6012]
#define sipNameNr_MagneticFluxDensity2D 6034
#define sipName_MagneticFluxDensity2D &sipStrings_QtBluetooth[6034]
#define sipNameNr_MagneticFluxDensity3D 6056
#define sipName_MagneticFluxDensity3D &sipStrings_QtBluetooth[6056]
#define sipNameNr_NetworkLoadFactorFive 6078
#define sipName_NetworkLoadFactorFive &sipStrings_QtBluetooth[6078]
#define sipNameNr_NetworkLoadFactorFour 6100
#define sipName_NetworkLoadFactorFour &sipStrings_QtBluetooth[6100]
#define sipNameNr_ObjectTransferService 6122
#define sipName_ObjectTransferService &sipStrings_QtBluetooth[6122]
#define sipNameNr_PeripheralPrivacyFlag 6144
#define sipName_PeripheralPrivacyFlag &sipStrings_QtBluetooth[6144]
#define sipNameNr_QBluetoothLocalDevice 6166
#define sipName_QBluetoothLocalDevice &sipStrings_QtBluetooth[6166]
#define sipNameNr_QBluetoothServiceInfo 6188
#define sipName_QBluetoothServiceInfo &sipStrings_QtBluetooth[6188]
#define sipNameNr_6210 6210
#define sipName_6210 &sipStrings_QtBluetooth[6210]
#define sipNameNr_QLowEnergyServiceData 6232
#define sipName_QLowEnergyServiceData &sipStrings_QtBluetooth[6232]
#define sipNameNr_RemoteHostClosedError 6254
#define sipName_RemoteHostClosedError &sipStrings_QtBluetooth[6254]
#define sipNameNr_ServiceInfoTimeToLive 6276
#define sipName_ServiceInfoTimeToLive &sipStrings_QtBluetooth[6276]
#define sipNameNr_UncategorizedComputer 6298
#define sipName_UncategorizedComputer &sipStrings_QtBluetooth[6298]
#define sipNameNr_UnknownDescriptorType 6320
#define sipName_UnknownDescriptorType &sipStrings_QtBluetooth[6320]
#define sipNameNr_WearableHeadsetDevice 6342
#define sipName_WearableHeadsetDevice &sipStrings_QtBluetooth[6342]
#define sipNameNr_characteristicChanged 6364
#define sipName_characteristicChanged &sipStrings_QtBluetooth[6364]
#define sipNameNr_characteristicWritten 6386
#define sipName_characteristicWritten &sipStrings_QtBluetooth[6386]
#define sipNameNr_disconnectFromService 6408
#define sipName_disconnectFromService &sipStrings_QtBluetooth[6408]
#define sipNameNr_hasPendingConnections 6430
#define sipName_hasPendingConnections &sipStrings_QtBluetooth[6430]
#define sipNameNr_invalidManufacturerId 6452
#define sipName_invalidManufacturerId &sipStrings_QtBluetooth[6452]
#define sipNameNr_maxPendingConnections 6474
#define sipName_maxPendingConnections &sipStrings_QtBluetooth[6474]
#define sipNameNr_nextPendingConnection 6496
#define sipName_nextPendingConnection &sipStrings_QtBluetooth[6496]
#define sipNameNr_setCoreConfigurations 6518
#define sipName_setCoreConfigurations &sipStrings_QtBluetooth[6518]
#define sipNameNr_setServiceDescription 6540
#define sipName_setServiceDescription &sipStrings_QtBluetooth[6540]
#define sipNameNr_setSupervisionTimeout 6562
#define sipName_setSupervisionTimeout &sipStrings_QtBluetooth[6562]
#define sipNameNr_BloodPressureFeature 6584
#define sipName_BloodPressureFeature &sipStrings_QtBluetooth[6584]
#define sipNameNr_BootMouseInputReport 6605
#define sipName_BootMouseInputReport &sipStrings_QtBluetooth[6605]
#define sipNameNr_CCCDEnableIndication 6626
#define sipName_CCCDEnableIndication &sipStrings_QtBluetooth[6626]
#define sipNameNr_CardReaderPeripheral 6647
#define sipName_CardReaderPeripheral &sipStrings_QtBluetooth[6647]
#define sipNameNr_DescriptorWriteError 6668
#define sipName_DescriptorWriteError &sipStrings_QtBluetooth[6668]
#define sipNameNr_EnvironmentalSensing 6689
#define sipName_EnvironmentalSensing &sipStrings_QtBluetooth[6689]
#define sipNameNr_HardcopyNotification 6710
#define sipName_HardcopyNotification &sipStrings_QtBluetooth[6710]
#define sipNameNr_HeartRateMeasurement 6731
#define sipName_HeartRateMeasurement &sipStrings_QtBluetooth[6731]
#define sipNameNr_HumanInterfaceDevice 6752
#define sipName_HumanInterfaceDevice &sipStrings_QtBluetooth[6752]
#define sipNameNr_LocalTimeInformation 6773
#define sipName_LocalTimeInformation &sipStrings_QtBluetooth[6773]
#define sipNameNr_MessageAccessProfile 6794
#define sipName_MessageAccessProfile &sipStrings_QtBluetooth[6794]
#define sipNameNr_MinorAudioVideoClass 503
#define sipName_MinorAudioVideoClass &sipStrings_QtBluetooth[503]
#define sipNameNr_MinorPeripheralClass 546
#define sipName_MinorPeripheralClass &sipStrings_QtBluetooth[546]
#define sipNameNr_NetworkLoadFactorOne 6815
#define sipName_NetworkLoadFactorOne &sipStrings_QtBluetooth[6815]
#define sipNameNr_NetworkLoadFactorSix 6836
#define sipName_NetworkLoadFactorSix &sipStrings_QtBluetooth[6836]
#define sipNameNr_NetworkLoadFactorTwo 6857
#define sipName_NetworkLoadFactorTwo &sipStrings_QtBluetooth[6857]
#define sipNameNr_NextDSTChangeService 6878
#define sipName_NextDSTChangeService &sipStrings_QtBluetooth[6878]
#define sipNameNr_QBluetooth__Security 6899
#define sipName_QBluetooth__Security &sipStrings_QtBluetooth[6899]
#define sipNameNr_QBluetoothDeviceInfo 6920
#define sipName_QBluetoothDeviceInfo &sipStrings_QtBluetooth[6920]
#define sipNameNr_QLowEnergyController 6941
#define sipName_QLowEnergyController &sipStrings_QtBluetooth[6941]
#define sipNameNr_QLowEnergyDescriptor 6962
#define sipName_QLowEnergyDescriptor &sipStrings_QtBluetooth[6962]
#define sipNameNr_ServiceNotFoundError 6983
#define sipName_ServiceNotFoundError &sipStrings_QtBluetooth[6983]
#define sipNameNr_ServiceTypeSecondary 7004
#define sipName_ServiceTypeSecondary &sipStrings_QtBluetooth[7004]
#define sipNameNr_WriteWithoutResponse 7025
#define sipName_WriteWithoutResponse &sipStrings_QtBluetooth[7025]
#define sipNameNr_disconnectFromDevice 7046
#define sipName_disconnectFromDevice &sipStrings_QtBluetooth[7046]
#define sipNameNr_hostModeStateChanged 7067
#define sipName_hostModeStateChanged &sipStrings_QtBluetooth[7067]
#define sipNameNr_serviceClassToString 7088
#define sipName_serviceClassToString &sipStrings_QtBluetooth[7088]
#define sipNameNr_setIncludePowerLevel 7109
#define sipName_setIncludePowerLevel &sipStrings_QtBluetooth[7109]
#define sipNameNr_setRemoteAddressType 7130
#define sipName_setRemoteAddressType &sipStrings_QtBluetooth[7130]
#define sipNameNr_AttAccessConstraint 2177
#define sipName_AttAccessConstraint &sipStrings_QtBluetooth[2177]
#define sipNameNr_ClientExecutableUrl 7151
#define sipName_ClientExecutableUrl &sipStrings_QtBluetooth[7151]
#define sipNameNr_CyclingPowerFeature 7171
#define sipName_CyclingPowerFeature &sipStrings_QtBluetooth[7171]
#define sipNameNr_DescriptorReadError 7191
#define sipName_DescriptorReadError &sipStrings_QtBluetooth[7191]
#define sipNameNr_DiscoverabilityNone 7211
#define sipName_DiscoverabilityNone &sipStrings_QtBluetooth[7211]
#define sipNameNr_GenericFileTransfer 7231
#define sipName_GenericFileTransfer &sipStrings_QtBluetooth[7231]
#define sipNameNr_HardcopyDataChannel 7251
#define sipName_HardcopyDataChannel &sipStrings_QtBluetooth[7251]
#define sipNameNr_HealthPulseOximeter 7271
#define sipName_HealthPulseOximeter &sipStrings_QtBluetooth[7271]
#define sipNameNr_MagneticDeclination 7291
#define sipName_MagneticDeclination &sipStrings_QtBluetooth[7291]
#define sipNameNr_MeasurementInterval 7311
#define sipName_MeasurementInterval &sipStrings_QtBluetooth[7311]
#define sipNameNr_MessageAccessServer 7331
#define sipName_MessageAccessServer &sipStrings_QtBluetooth[7331]
#define sipNameNr_MiscellaneousDevice 7351
#define sipName_MiscellaneousDevice &sipStrings_QtBluetooth[7351]
#define sipNameNr_PollenConcentration 7371
#define sipName_PollenConcentration &sipStrings_QtBluetooth[7371]
#define sipNameNr_PortableAudioDevice 7391
#define sipName_PortableAudioDevice &sipStrings_QtBluetooth[7391]
#define sipNameNr_PrimaryLanguageBase 7411
#define sipName_PrimaryLanguageBase &sipStrings_QtBluetooth[7411]
#define sipNameNr_ReconnectionAddress 7431
#define sipName_ReconnectionAddress &sipStrings_QtBluetooth[7431]
#define sipNameNr_ServiceAvailability 5860
#define sipName_ServiceAvailability &sipStrings_QtBluetooth[5860]
#define sipNameNr_ServiceRecordHandle 7451
#define sipName_ServiceRecordHandle &sipStrings_QtBluetooth[7451]
#define sipNameNr_UncategorizedDevice 7471
#define sipName_UncategorizedDevice &sipStrings_QtBluetooth[7471]
#define sipNameNr_createServiceObject 7491
#define sipName_createServiceObject &sipStrings_QtBluetooth[7491]
#define sipNameNr_serviceAvailability 7511
#define sipName_serviceAvailability &sipStrings_QtBluetooth[7511]
#define sipNameNr_setIncludedServices 7531
#define sipName_setIncludedServices &sipStrings_QtBluetooth[7531]
#define sipNameNr_setManufacturerData 7551
#define sipName_setManufacturerData &sipStrings_QtBluetooth[7551]
#define sipNameNr_setSocketDescriptor 7571
#define sipName_setSocketDescriptor &sipStrings_QtBluetooth[7571]
#define sipNameNr_setWriteConstraints 7591
#define sipName_setWriteConstraints &sipStrings_QtBluetooth[7591]
#define sipNameNr_setWritePermissions 7611
#define sipName_setWritePermissions &sipStrings_QtBluetooth[7611]
#define sipNameNr_waitForBytesWritten 7631
#define sipName_waitForBytesWritten &sipStrings_QtBluetooth[7631]
#define sipNameNr_writeCharacteristic 7651
#define sipName_writeCharacteristic &sipStrings_QtBluetooth[7651]
#define sipNameNr_AnaerobicThreshold 7671
#define sipName_AnaerobicThreshold &sipStrings_QtBluetooth[7671]
#define sipNameNr_AuthorizationError 7690
#define sipName_AuthorizationError &sipStrings_QtBluetooth[7690]
#define sipNameNr_BodySensorLocation 7709
#define sipName_BodySensorLocation &sipStrings_QtBluetooth[7709]
#define sipNameNr_CharacteristicType 1778
#define sipName_CharacteristicType &sipStrings_QtBluetooth[1778]
#define sipNameNr_CurrentTimeService 7728
#define sipName_CurrentTimeService &sipStrings_QtBluetooth[7728]
#define sipNameNr_CyclingPowerVector 7747
#define sipName_CyclingPowerVector &sipStrings_QtBluetooth[7747]
#define sipNameNr_DiscoveringService 7766
#define sipName_DiscoveringService &sipStrings_QtBluetooth[7766]
#define sipNameNr_GlucoseMeasurement 7785
#define sipName_GlucoseMeasurement &sipStrings_QtBluetooth[7785]
#define sipNameNr_HealthGlucoseMeter 7804
#define sipName_HealthGlucoseMeter &sipStrings_QtBluetooth[7804]
#define sipNameNr_InformationService 7823
#define sipName_InformationService &sipStrings_QtBluetooth[7823]
#define sipNameNr_JoystickPeripheral 7842
#define sipName_JoystickPeripheral &sipStrings_QtBluetooth[7842]
#define sipNameNr_KeyboardPeripheral 7861
#define sipName_KeyboardPeripheral &sipStrings_QtBluetooth[7861]
#define sipNameNr_McapControlChannel 7880
#define sipName_McapControlChannel &sipStrings_QtBluetooth[7880]
#define sipNameNr_MinorComputerClass 675
#define sipName_MinorComputerClass &sipStrings_QtBluetooth[675]
#define sipNameNr_MinorWearableClass 716
#define sipName_MinorWearableClass &sipStrings_QtBluetooth[716]
#define sipNameNr_NetworkFullService 7899
#define sipName_NetworkFullService &sipStrings_QtBluetooth[7899]
#define sipNameNr_PhonebookAccessPCE 7918
#define sipName_PhonebookAccessPCE &sipStrings_QtBluetooth[7918]
#define sipNameNr_PhonebookAccessPSE 7937
#define sipName_PhonebookAccessPSE &sipStrings_QtBluetooth[7937]
#define sipNameNr_PositioningService 7956
#define sipName_PositioningService &sipStrings_QtBluetooth[7956]
#define sipNameNr_QBluetoothHostInfo 7975
#define sipName_QBluetoothHostInfo &sipStrings_QtBluetooth[7975]
#define sipNameNr_RingerControlPoint 7994
#define sipName_RingerControlPoint &sipStrings_QtBluetooth[7994]
#define sipNameNr_ScanIntervalWindow 8013
#define sipName_ScanIntervalWindow &sipStrings_QtBluetooth[8013]
#define sipNameNr_SerialNumberString 8032
#define sipName_SerialNumberString &sipStrings_QtBluetooth[8032]
#define sipNameNr_ServiceDescription 6543
#define sipName_ServiceDescription &sipStrings_QtBluetooth[6543]
#define sipNameNr_ServiceLookupState 8051
#define sipName_ServiceLookupState &sipStrings_QtBluetooth[8051]
#define sipNameNr_ServiceRecordState 8070
#define sipName_ServiceRecordState &sipStrings_QtBluetooth[8070]
#define sipNameNr_ServiceTypePrimary 8089
#define sipName_ServiceTypePrimary &sipStrings_QtBluetooth[8089]
#define sipNameNr_SkipValueDiscovery 8108
#define sipName_SkipValueDiscovery &sipStrings_QtBluetooth[8108]
#define sipNameNr_UncategorizedPhone 8127
#define sipName_UncategorizedPhone &sipStrings_QtBluetooth[8127]
#define sipNameNr_UnknownSocketError 8146
#define sipName_UnknownSocketError &sipStrings_QtBluetooth[8146]
#define sipNameNr_WaistCircumference 8165
#define sipName_WaistCircumference &sipStrings_QtBluetooth[8165]
#define sipNameNr_WearableWristWatch 8184
#define sipName_WearableWristWatch &sipStrings_QtBluetooth[8184]
#define sipNameNr_WeightScaleFeature 8203
#define sipName_WeightScaleFeature &sipStrings_QtBluetooth[8203]
#define sipNameNr_addIncludedService 8222
#define sipName_addIncludedService &sipStrings_QtBluetooth[8222]
#define sipNameNr_characteristicRead 8241
#define sipName_characteristicRead &sipStrings_QtBluetooth[8241]
#define sipNameNr_coreConfigurations 8260
#define sipName_coreConfigurations &sipStrings_QtBluetooth[8260]
#define sipNameNr_descriptorToString 8279
#define sipName_descriptorToString &sipStrings_QtBluetooth[8279]
#define sipNameNr_deviceDisconnected 8298
#define sipName_deviceDisconnected &sipStrings_QtBluetooth[8298]
#define sipNameNr_discoveredServices 8317
#define sipName_discoveredServices &sipStrings_QtBluetooth[8317]
#define sipNameNr_maximumValueLength 8336
#define sipName_maximumValueLength &sipStrings_QtBluetooth[8336]
#define sipNameNr_minimumValueLength 8355
#define sipName_minimumValueLength &sipStrings_QtBluetooth[8355]
#define sipNameNr_protocolDescriptor 8374
#define sipName_protocolDescriptor &sipStrings_QtBluetooth[8374]
#define sipNameNr_readCharacteristic 8393
#define sipName_readCharacteristic &sipStrings_QtBluetooth[8393]
#define sipNameNr_serviceDescription 8412
#define sipName_serviceDescription &sipStrings_QtBluetooth[8412]
#define sipNameNr_setCharacteristics 8431
#define sipName_setCharacteristics &sipStrings_QtBluetooth[8431]
#define sipNameNr_setDiscoverability 8450
#define sipName_setDiscoverability &sipStrings_QtBluetooth[8450]
#define sipNameNr_setReadConstraints 8469
#define sipName_setReadConstraints &sipStrings_QtBluetooth[8469]
#define sipNameNr_setReadPermissions 8488
#define sipName_setReadPermissions &sipStrings_QtBluetooth[8488]
#define sipNameNr_setServiceProvider 8507
#define sipName_setServiceProvider &sipStrings_QtBluetooth[8507]
#define sipNameNr_supervisionTimeout 8526
#define sipName_supervisionTimeout &sipStrings_QtBluetooth[8526]
#define sipNameNr_ApparentWindSpeed 8545
#define sipName_ApparentWindSpeed &sipStrings_QtBluetooth[8545]
#define sipNameNr_CoreConfiguration 797
#define sipName_CoreConfiguration &sipStrings_QtBluetooth[797]
#define sipNameNr_DeviceInformation 8563
#define sipName_DeviceInformation &sipStrings_QtBluetooth[8563]
#define sipNameNr_DiscoveryRequired 8581
#define sipName_DiscoveryRequired &sipStrings_QtBluetooth[8581]
#define sipNameNr_GamepadPeripheral 8599
#define sipName_GamepadPeripheral &sipStrings_QtBluetooth[8599]
#define sipNameNr_GenericNetworking 8617
#define sipName_GenericNetworking &sipStrings_QtBluetooth[8617]
#define sipNameNr_HealthDataDisplay 8635
#define sipName_HealthDataDisplay &sipStrings_QtBluetooth[8635]
#define sipNameNr_HealthStepCounter 8653
#define sipName_HealthStepCounter &sipStrings_QtBluetooth[8653]
#define sipNameNr_HealthThermometer 8671
#define sipName_HealthThermometer &sipStrings_QtBluetooth[8671]
#define sipNameNr_HealthWeightScale 8689
#define sipName_HealthWeightScale &sipStrings_QtBluetooth[8689]
#define sipNameNr_HostNotFoundError 8707
#define sipName_HostNotFoundError &sipStrings_QtBluetooth[8707]
#define sipNameNr_LANAccessUsingPPP 8725
#define sipName_LANAccessUsingPPP &sipStrings_QtBluetooth[8725]
#define sipNameNr_MinorImagingClass 837
#define sipName_MinorImagingClass &sipStrings_QtBluetooth[837]
#define sipNameNr_MinorNetworkClass 877
#define sipName_MinorNetworkClass &sipStrings_QtBluetooth[877]
#define sipNameNr_ModelNumberString 8743
#define sipName_ModelNumberString &sipStrings_QtBluetooth[8743]
#define sipNameNr_NetworkingService 8761
#define sipName_NetworkingService &sipStrings_QtBluetooth[8761]
#define sipNameNr_PublicBrowseGroup 8779
#define sipName_PublicBrowseGroup &sipStrings_QtBluetooth[8779]
#define sipNameNr_PyQt6_QtBluetooth 8797
#define sipName_PyQt6_QtBluetooth &sipStrings_QtBluetooth[8797]
#define sipNameNr_QBluetoothAddress 8815
#define sipName_QBluetoothAddress &sipStrings_QtBluetooth[8815]
#define sipNameNr_QLowEnergyService 8833
#define sipName_QLowEnergyService &sipStrings_QtBluetooth[8833]
#define sipNameNr_ReferencePrinting 8851
#define sipName_ReferencePrinting &sipStrings_QtBluetooth[8851]
#define sipNameNr_RemoteAddressType 957
#define sipName_RemoteAddressType &sipStrings_QtBluetooth[957]
#define sipNameNr_ServiceDiscovered 5260
#define sipName_ServiceDiscovered &sipStrings_QtBluetooth[5260]
#define sipNameNr_Synchronization3D 8869
#define sipName_Synchronization3D &sipStrings_QtBluetooth[8869]
#define sipNameNr_TrueWindDirection 8887
#define sipName_TrueWindDirection &sipStrings_QtBluetooth[8887]
#define sipNameNr_UnreadAlertStatus 8905
#define sipName_UnreadAlertStatus &sipStrings_QtBluetooth[8905]
#define sipNameNr_VideoConferencing 8923
#define sipName_VideoConferencing &sipStrings_QtBluetooth[8923]
#define sipNameNr_VideoDistribution 8941
#define sipName_VideoDistribution &sipStrings_QtBluetooth[8941]
#define sipNameNr_WeightMeasurement 8959
#define sipName_WeightMeasurement &sipStrings_QtBluetooth[8959]
#define sipNameNr_WriteWithResponse 8977
#define sipName_WriteWithResponse &sipStrings_QtBluetooth[8977]
#define sipNameNr_addCharacteristic 8995
#define sipName_addCharacteristic &sipStrings_QtBluetooth[8995]
#define sipNameNr_connectionUpdated 9013
#define sipName_connectionUpdated &sipStrings_QtBluetooth[9013]
#define sipNameNr_descriptorWritten 9031
#define sipName_descriptorWritten &sipStrings_QtBluetooth[9031]
#define sipNameNr_discoveredDevices 9049
#define sipName_discoveredDevices &sipStrings_QtBluetooth[9049]
#define sipNameNr_discoveryFinished 9067
#define sipName_discoveryFinished &sipStrings_QtBluetooth[9067]
#define sipNameNr_doDeviceDiscovery 9085
#define sipName_doDeviceDiscovery &sipStrings_QtBluetooth[9085]
#define sipNameNr_includePowerLevel 9103
#define sipName_includePowerLevel &sipStrings_QtBluetooth[9103]
#define sipNameNr_remoteAddressType 9121
#define sipName_remoteAddressType &sipStrings_QtBluetooth[9121]
#define sipNameNr_serviceClassUuids 9139
#define sipName_serviceClassUuids &sipStrings_QtBluetooth[9139]
#define sipNameNr_serviceDiscovered 9157
#define sipName_serviceDiscovered &sipStrings_QtBluetooth[9157]
#define sipNameNr_unregisterService 9175
#define sipName_unregisterService &sipStrings_QtBluetooth[9175]
#define sipNameNr_AV_RemoteControl 9193
#define sipName_AV_RemoteControl &sipStrings_QtBluetooth[9193]
#define sipNameNr_AdvertisingError 9210
#define sipName_AdvertisingError &sipStrings_QtBluetooth[9210]
#define sipNameNr_AdvertisingState 9227
#define sipName_AdvertisingState &sipStrings_QtBluetooth[9227]
#define sipNameNr_AerobicThreshold 9244
#define sipName_AerobicThreshold &sipStrings_QtBluetooth[9244]
#define sipNameNr_AudioVideoDevice 2956
#define sipName_AudioVideoDevice &sipStrings_QtBluetooth[2956]
#define sipNameNr_AuthorizedPaired 9261
#define sipName_AuthorizedPaired &sipStrings_QtBluetooth[9261]
#define sipNameNr_CapturingService 9278
#define sipName_CapturingService &sipStrings_QtBluetooth[9278]
#define sipNameNr_DialupNetworking 9295
#define sipName_DialupNetworking &sipStrings_QtBluetooth[9295]
#define sipNameNr_DiscoveringState 9312
#define sipName_DiscoveringState &sipStrings_QtBluetooth[9312]
#define sipNameNr_DocumentationUrl 9329
#define sipName_DocumentationUrl &sipStrings_QtBluetooth[9329]
#define sipNameNr_ExtendedProperty 9346
#define sipName_ExtendedProperty &sipStrings_QtBluetooth[9346]
#define sipNameNr_GenericAttribute 9363
#define sipName_GenericAttribute &sipStrings_QtBluetooth[9363]
#define sipNameNr_GenericTelephony 9380
#define sipName_GenericTelephony &sipStrings_QtBluetooth[9380]
#define sipNameNr_HandheldComputer 9397
#define sipName_HandheldComputer &sipStrings_QtBluetooth[9397]
#define sipNameNr_HipCircumference 9414
#define sipName_HipCircumference &sipStrings_QtBluetooth[9414]
#define sipNameNr_HostDiscoverable 9431
#define sipName_HostDiscoverable &sipStrings_QtBluetooth[9431]
#define sipNameNr_ImagingResponder 9448
#define sipName_ImagingResponder &sipStrings_QtBluetooth[9448]
#define sipNameNr_InputOutputError 9465
#define sipName_InputOutputError &sipStrings_QtBluetooth[9465]
#define sipNameNr_LocationAndSpeed 9482
#define sipName_LocationAndSpeed &sipStrings_QtBluetooth[9482]
#define sipNameNr_MajorDeviceClass 997
#define sipName_MajorDeviceClass &sipStrings_QtBluetooth[997]
#define sipNameNr_ManufacturerData 7554
#define sipName_ManufacturerData &sipStrings_QtBluetooth[7554]
#define sipNameNr_MinimalDiscovery 9499
#define sipName_MinimalDiscovery &sipStrings_QtBluetooth[9499]
#define sipNameNr_MinorHealthClass 1036
#define sipName_MinorHealthClass &sipStrings_QtBluetooth[1036]
#define sipNameNr_NetworkNoService 9516
#define sipName_NetworkNoService &sipStrings_QtBluetooth[9516]
#define sipNameNr_OBEXFileTransfer 9533
#define sipName_OBEXFileTransfer &sipStrings_QtBluetooth[9533]
#define sipNameNr_PeripheralDevice 9550
#define sipName_PeripheralDevice &sipStrings_QtBluetooth[9550]
#define sipNameNr_QBluetoothServer 9567
#define sipName_QBluetoothServer &sipStrings_QtBluetooth[9567]
#define sipNameNr_QBluetoothSocket 9584
#define sipName_QBluetoothSocket &sipStrings_QtBluetooth[9584]
#define sipNameNr_RenderingService 9601
#define sipName_RenderingService &sipStrings_QtBluetooth[9601]
#define sipNameNr_RestingHeartRate 9618
#define sipName_RestingHeartRate &sipStrings_QtBluetooth[9618]
#define sipNameNr_ServiceClassUuid 2083
#define sipName_ServiceClassUuid &sipStrings_QtBluetooth[2083]
#define sipNameNr_TelephonyService 9635
#define sipName_TelephonyService &sipStrings_QtBluetooth[9635]
#define sipNameNr_UncategorizedToy 9652
#define sipName_UncategorizedToy &sipStrings_QtBluetooth[9652]
#define sipNameNr_UnconnectedState 9669
#define sipName_UnconnectedState &sipStrings_QtBluetooth[9669]
#define sipNameNr_UserControlPoint 9686
#define sipName_UserControlPoint &sipStrings_QtBluetooth[9686]
#define sipNameNr_WearableComputer 9703
#define sipName_WearableComputer &sipStrings_QtBluetooth[9703]
#define sipNameNr_connectToService 9720
#define sipName_connectToService &sipStrings_QtBluetooth[9720]
#define sipNameNr_connectedDevices 9737
#define sipName_connectedDevices &sipStrings_QtBluetooth[9737]
#define sipNameNr_createPeripheral 9754
#define sipName_createPeripheral &sipStrings_QtBluetooth[9754]
#define sipNameNr_deviceDiscovered 9771
#define sipName_deviceDiscovered &sipStrings_QtBluetooth[9771]
#define sipNameNr_disconnectNotify 9788
#define sipName_disconnectNotify &sipStrings_QtBluetooth[9788]
#define sipNameNr_discoverServices 9805
#define sipName_discoverServices &sipStrings_QtBluetooth[9805]
#define sipNameNr_includedServices 9822
#define sipName_includedServices &sipStrings_QtBluetooth[9822]
#define sipNameNr_majorDeviceClass 9839
#define sipName_majorDeviceClass &sipStrings_QtBluetooth[9839]
#define sipNameNr_manufacturerData 9856
#define sipName_manufacturerData &sipStrings_QtBluetooth[9856]
#define sipNameNr_minorDeviceClass 9873
#define sipName_minorDeviceClass &sipStrings_QtBluetooth[9873]
#define sipNameNr_protocolToString 9890
#define sipName_protocolToString &sipStrings_QtBluetooth[9890]
#define sipNameNr_remoteDeviceUuid 9907
#define sipName_remoteDeviceUuid &sipStrings_QtBluetooth[9907]
#define sipNameNr_scanResponseData 9924
#define sipName_scanResponseData &sipStrings_QtBluetooth[9924]
#define sipNameNr_setIntervalRange 9941
#define sipName_setIntervalRange &sipStrings_QtBluetooth[9941]
#define sipNameNr_setRemoteAddress 9958
#define sipName_setRemoteAddress &sipStrings_QtBluetooth[9958]
#define sipNameNr_setSecurityFlags 9975
#define sipName_setSecurityFlags &sipStrings_QtBluetooth[9975]
#define sipNameNr_socketDescriptor 9992
#define sipName_socketDescriptor &sipStrings_QtBluetooth[9992]
#define sipNameNr_startAdvertising 10009
#define sipName_startAdvertising &sipStrings_QtBluetooth[10009]
#define sipNameNr_waitForReadyRead 10026
#define sipName_waitForReadyRead &sipStrings_QtBluetooth[10026]
#define sipNameNr_writeConstraints 10043
#define sipName_writeConstraints &sipStrings_QtBluetooth[10043]
#define sipNameNr_AlertCategoryID 10060
#define sipName_AlertCategoryID &sipStrings_QtBluetooth[10060]
#define sipNameNr_BodyComposition 10076
#define sipName_BodyComposition &sipStrings_QtBluetooth[10076]
#define sipNameNr_BrowseGroupList 10092
#define sipName_BrowseGroupList &sipStrings_QtBluetooth[10092]
#define sipNameNr_ConnectingState 10108
#define sipName_ConnectingState &sipStrings_QtBluetooth[10108]
#define sipNameNr_ConnectionError 10124
#define sipName_ConnectionError &sipStrings_QtBluetooth[10124]
#define sipNameNr_ControllerState 1421
#define sipName_ControllerState &sipStrings_QtBluetooth[1421]
#define sipNameNr_DesktopComputer 10140
#define sipName_DesktopComputer &sipStrings_QtBluetooth[10140]
#define sipNameNr_Discoverability 637
#define sipName_Discoverability &sipStrings_QtBluetooth[637]
#define sipNameNr_DiscoveredState 10156
#define sipName_DiscoveredState &sipStrings_QtBluetooth[10156]
#define sipNameNr_DiscoveryMethod 140
#define sipName_DiscoveryMethod &sipStrings_QtBluetooth[140]
#define sipNameNr_HIDControlPoint 10172
#define sipName_HIDControlPoint &sipStrings_QtBluetooth[10172]
#define sipNameNr_HandsFreeDevice 10188
#define sipName_HandsFreeDevice &sipStrings_QtBluetooth[10188]
#define sipNameNr_HiFiAudioDevice 10204
#define sipName_HiFiAudioDevice &sipStrings_QtBluetooth[10204]
#define sipNameNr_HostConnectable 10220
#define sipName_HostConnectable &sipStrings_QtBluetooth[10220]
#define sipNameNr_IgnoreWhiteList 10236
#define sipName_IgnoreWhiteList &sipStrings_QtBluetooth[10236]
#define sipNameNr_IncludedService 8225
#define sipName_IncludedService &sipStrings_QtBluetooth[8225]
#define sipNameNr_IrMCSyncCommand 10252
#define sipName_IrMCSyncCommand &sipStrings_QtBluetooth[10252]
#define sipNameNr_LowEnergyMethod 10268
#define sipName_LowEnergyMethod &sipStrings_QtBluetooth[10268]
#define sipNameNr_McapDataChannel 10284
#define sipName_McapDataChannel &sipStrings_QtBluetooth[10284]
#define sipNameNr_MinorPhoneClass 1345
#define sipName_MinorPhoneClass &sipStrings_QtBluetooth[1345]
#define sipNameNr_PhonebookAccess 10300
#define sipName_PhonebookAccess &sipStrings_QtBluetooth[10300]
#define sipNameNr_PositionQuality 10316
#define sipName_PositionQuality &sipStrings_QtBluetooth[10316]
#define sipNameNr_PoweredOffError 10332
#define sipName_PoweredOffError &sipStrings_QtBluetooth[10332]
#define sipNameNr_ReportReference 5022
#define sipName_ReportReference &sipStrings_QtBluetooth[5022]
#define sipNameNr_ServiceClassIds 10348
#define sipName_ServiceClassIds &sipStrings_QtBluetooth[10348]
#define sipNameNr_ServiceProvider 8510
#define sipName_ServiceProvider &sipStrings_QtBluetooth[8510]
#define sipNameNr_TemperatureType 10364
#define sipName_TemperatureType &sipStrings_QtBluetooth[10364]
#define sipNameNr_TimeUpdateState 10380
#define sipName_TimeUpdateState &sipStrings_QtBluetooth[10380]
#define sipNameNr_UnknownProtocol 10396
#define sipName_UnknownProtocol &sipStrings_QtBluetooth[10396]
#define sipNameNr_WearableGlasses 10412
#define sipName_WearableGlasses &sipStrings_QtBluetooth[10412]
#define sipNameNr_WriteNoResponse 10428
#define sipName_WriteNoResponse &sipStrings_QtBluetooth[10428]
#define sipNameNr_characteristics 10444
#define sipName_characteristics &sipStrings_QtBluetooth[10444]
#define sipNameNr_connectToDevice 10460
#define sipName_connectToDevice &sipStrings_QtBluetooth[10460]
#define sipNameNr_deviceConnected 10476
#define sipName_deviceConnected &sipStrings_QtBluetooth[10476]
#define sipNameNr_discoverDetails 10492
#define sipName_discoverDetails &sipStrings_QtBluetooth[10492]
#define sipNameNr_discoverability 10508
#define sipName_discoverability &sipStrings_QtBluetooth[10508]
#define sipNameNr_manufacturerIds 10524
#define sipName_manufacturerIds &sipStrings_QtBluetooth[10524]
#define sipNameNr_maximumInterval 10540
#define sipName_maximumInterval &sipStrings_QtBluetooth[10540]
#define sipNameNr_minimumInterval 10556
#define sipName_minimumInterval &sipStrings_QtBluetooth[10556]
#define sipNameNr_pairingFinished 10572
#define sipName_pairingFinished &sipStrings_QtBluetooth[10572]
#define sipNameNr_readConstraints 10588
#define sipName_readConstraints &sipStrings_QtBluetooth[10588]
#define sipNameNr_registerService 9177
#define sipName_registerService &sipStrings_QtBluetooth[9177]
#define sipNameNr_removeAttribute 10604
#define sipName_removeAttribute &sipStrings_QtBluetooth[10604]
#define sipNameNr_serviceProvider 10620
#define sipName_serviceProvider &sipStrings_QtBluetooth[10620]
#define sipNameNr_setServiceUuids 10636
#define sipName_setServiceUuids &sipStrings_QtBluetooth[10636]
#define sipNameNr_stopAdvertising 10652
#define sipName_stopAdvertising &sipStrings_QtBluetooth[10652]
#define sipNameNr_writeDescriptor 10668
#define sipName_writeDescriptor &sipStrings_QtBluetooth[10668]
#define sipNameNr_Authentication 10684
#define sipName_Authentication &sipStrings_QtBluetooth[10684]
#define sipNameNr_BatteryService 10699
#define sipName_BatteryService &sipStrings_QtBluetooth[10699]
#define sipNameNr_BondManagement 10714
#define sipName_BondManagement &sipStrings_QtBluetooth[10714]
#define sipNameNr_CSCMeasurement 10729
#define sipName_CSCMeasurement &sipStrings_QtBluetooth[10729]
#define sipNameNr_ComputerDevice 10744
#define sipName_ComputerDevice &sipStrings_QtBluetooth[10744]
#define sipNameNr_ConnectedState 10759
#define sipName_ConnectedState &sipStrings_QtBluetooth[10759]
#define sipNameNr_DescriptorType 2625
#define sipName_DescriptorType &sipStrings_QtBluetooth[2625]
#define sipNameNr_DirectPrinting 10774
#define sipName_DirectPrinting &sipStrings_QtBluetooth[10774]
#define sipNameNr_GlucoseFeature 10789
#define sipName_GlucoseFeature &sipStrings_QtBluetooth[10789]
#define sipNameNr_HIDInformation 10804
#define sipName_HIDInformation &sipStrings_QtBluetooth[10804]
#define sipNameNr_HostPoweredOff 10819
#define sipName_HostPoweredOff &sipStrings_QtBluetooth[10819]
#define sipNameNr_ImmediateAlert 10834
#define sipName_ImmediateAlert &sipStrings_QtBluetooth[10834]
#define sipNameNr_InvalidService 10849
#define sipName_InvalidService &sipStrings_QtBluetooth[10849]
#define sipNameNr_LNControlPoint 10864
#define sipName_LNControlPoint &sipStrings_QtBluetooth[10864]
#define sipNameNr_LaptopComputer 10879
#define sipName_LaptopComputer &sipStrings_QtBluetooth[10879]
#define sipNameNr_ListeningState 10894
#define sipName_ListeningState &sipStrings_QtBluetooth[10894]
#define sipNameNr_ObexObjectPush 10909
#define sipName_ObexObjectPush &sipStrings_QtBluetooth[10909]
#define sipNameNr_OperationError 10924
#define sipName_OperationError &sipStrings_QtBluetooth[10924]
#define sipNameNr_PeripheralRole 10939
#define sipName_PeripheralRole &sipStrings_QtBluetooth[10939]
#define sipNameNr_PnPInformation 10954
#define sipName_PnPInformation &sipStrings_QtBluetooth[10954]
#define sipNameNr_PrimaryService 10969
#define sipName_PrimaryService &sipStrings_QtBluetooth[10969]
#define sipNameNr_PrintingStatus 10984
#define sipName_PrintingStatus &sipStrings_QtBluetooth[10984]
#define sipNameNr_QBluetoothUuid 10999
#define sipName_QBluetoothUuid &sipStrings_QtBluetooth[10999]
#define sipNameNr_RSCMeasurement 11014
#define sipName_RSCMeasurement &sipStrings_QtBluetooth[11014]
#define sipNameNr_RfcommProtocol 11029
#define sipName_RfcommProtocol &sipStrings_QtBluetooth[11029]
#define sipNameNr_SCControlPoint 11044
#define sipName_SCControlPoint &sipStrings_QtBluetooth[11044]
#define sipNameNr_ScanParameters 11059
#define sipName_ScanParameters &sipStrings_QtBluetooth[11059]
#define sipNameNr_SensorLocation 7713
#define sipName_SensorLocation &sipStrings_QtBluetooth[7713]
#define sipNameNr_ServerComputer 11074
#define sipName_ServerComputer &sipStrings_QtBluetooth[11074]
#define sipNameNr_ServiceChanged 11089
#define sipName_ServiceChanged &sipStrings_QtBluetooth[11089]
#define sipNameNr_WearableDevice 3559
#define sipName_WearableDevice &sipStrings_QtBluetooth[3559]
#define sipNameNr_WearableHelmet 11104
#define sipName_WearableHelmet &sipStrings_QtBluetooth[11104]
#define sipNameNr_WearableJacket 11119
#define sipName_WearableJacket &sipStrings_QtBluetooth[11119]
#define sipNameNr_bytesAvailable 11134
#define sipName_bytesAvailable &sipStrings_QtBluetooth[11134]
#define sipNameNr_characteristic 11149
#define sipName_characteristic &sipStrings_QtBluetooth[11149]
#define sipNameNr_descriptorRead 11164
#define sipName_descriptorRead &sipStrings_QtBluetooth[11164]
#define sipNameNr_manufacturerId 11179
#define sipName_manufacturerId &sipStrings_QtBluetooth[11179]
#define sipNameNr_readDescriptor 11194
#define sipName_readDescriptor &sipStrings_QtBluetooth[11194]
#define sipNameNr_requestPairing 11209
#define sipName_requestPairing &sipStrings_QtBluetooth[11209]
#define sipNameNr_serviceClasses 11224
#define sipName_serviceClasses &sipStrings_QtBluetooth[11224]
#define sipNameNr_setDescriptors 11239
#define sipName_setDescriptors &sipStrings_QtBluetooth[11239]
#define sipNameNr_setServiceData 11254
#define sipName_setServiceData &sipStrings_QtBluetooth[11254]
#define sipNameNr_setServiceName 11269
#define sipName_setServiceName &sipStrings_QtBluetooth[11269]
#define sipNameNr_setServiceUuid 11284
#define sipName_setServiceUuid &sipStrings_QtBluetooth[11284]
#define sipNameNr_setSocketError 11299
#define sipName_setSocketError &sipStrings_QtBluetooth[11299]
#define sipNameNr_setSocketState 11314
#define sipName_setSocketState &sipStrings_QtBluetooth[11314]
#define sipNameNr_setValueLength 11329
#define sipName_setValueLength &sipStrings_QtBluetooth[11329]
#define sipNameNr_socketProtocol 11344
#define sipName_socketProtocol &sipStrings_QtBluetooth[11344]
#define sipNameNr_AdvNonConnInd 11359
#define sipName_AdvNonConnInd &sipStrings_QtBluetooth[11359]
#define sipNameNr_Authorization 11373
#define sipName_Authorization &sipStrings_QtBluetooth[11373]
#define sipNameNr_BasicPrinting 11387
#define sipName_BasicPrinting &sipStrings_QtBluetooth[11387]
#define sipNameNr_BloodPressure 11401
#define sipName_BloodPressure &sipStrings_QtBluetooth[11401]
#define sipNameNr_CellularPhone 11415
#define sipName_CellularPhone &sipStrings_QtBluetooth[11415]
#define sipNameNr_ClassicMethod 11429
#define sipName_ClassicMethod &sipStrings_QtBluetooth[11429]
#define sipNameNr_CordlessPhone 11443
#define sipName_CordlessPhone &sipStrings_QtBluetooth[11443]
#define sipNameNr_DiscoveryMode 237
#define sipName_DiscoveryMode &sipStrings_QtBluetooth[237]
#define sipNameNr_FullDiscovery 11457
#define sipName_FullDiscovery &sipStrings_QtBluetooth[11457]
#define sipNameNr_GenericAccess 11471
#define sipName_GenericAccess &sipStrings_QtBluetooth[11471]
#define sipNameNr_ImagingDevice 3830
#define sipName_ImagingDevice &sipStrings_QtBluetooth[3830]
#define sipNameNr_L2capProtocol 11485
#define sipName_L2capProtocol &sipStrings_QtBluetooth[11485]
#define sipNameNr_MinorToyClass 1571
#define sipName_MinorToyClass &sipStrings_QtBluetooth[1571]
#define sipNameNr_NetworkDevice 11499
#define sipName_NetworkDevice &sipStrings_QtBluetooth[11499]
#define sipNameNr_NoSocketError 11513
#define sipName_NoSocketError &sipStrings_QtBluetooth[11513]
#define sipNameNr_PublicAddress 11527
#define sipName_PublicAddress &sipStrings_QtBluetooth[11527]
#define sipNameNr_RandomAddress 11541
#define sipName_RandomAddress &sipStrings_QtBluetooth[11541]
#define sipNameNr_RemoteService 11555
#define sipName_RemoteService &sipStrings_QtBluetooth[11555]
#define sipNameNr_RingerSetting 11569
#define sipName_RingerSetting &sipStrings_QtBluetooth[11569]
#define sipNameNr_RssiReadError 11583
#define sipName_RssiReadError &sipStrings_QtBluetooth[11583]
#define sipNameNr_ToyController 11597
#define sipName_ToyController &sipStrings_QtBluetooth[11597]
#define sipNameNr_TrueWindSpeed 11611
#define sipName_TrueWindSpeed &sipStrings_QtBluetooth[11611]
#define sipNameNr_WearablePager 11625
#define sipName_WearablePager &sipStrings_QtBluetooth[11625]
#define sipNameNr_addDescriptor 11639
#define sipName_addDescriptor &sipStrings_QtBluetooth[11639]
#define sipNameNr_connectNotify 9791
#define sipName_connectNotify &sipStrings_QtBluetooth[9791]
#define sipNameNr_createCentral 11653
#define sipName_createCentral &sipStrings_QtBluetooth[11653]
#define sipNameNr_deviceUpdated 11667
#define sipName_deviceUpdated &sipStrings_QtBluetooth[11667]
#define sipNameNr_errorOccurred 11681
#define sipName_errorOccurred &sipStrings_QtBluetooth[11681]
#define sipNameNr_newConnection 11695
#define sipName_newConnection &sipStrings_QtBluetooth[11695]
#define sipNameNr_pairingStatus 11709
#define sipName_pairingStatus &sipStrings_QtBluetooth[11709]
#define sipNameNr_remoteAddress 11723
#define sipName_remoteAddress &sipStrings_QtBluetooth[11723]
#define sipNameNr_securityFlags 11737
#define sipName_securityFlags &sipStrings_QtBluetooth[11737]
#define sipNameNr_serverAddress 11751
#define sipName_serverAddress &sipStrings_QtBluetooth[11751]
#define sipNameNr_serverChannel 11765
#define sipName_serverChannel &sipStrings_QtBluetooth[11765]
#define sipNameNr_setDeviceUuid 11779
#define sipName_setDeviceUuid &sipStrings_QtBluetooth[11779]
#define sipNameNr_setProperties 11793
#define sipName_setProperties &sipStrings_QtBluetooth[11793]
#define sipNameNr_setUuidFilter 11807
#define sipName_setUuidFilter &sipStrings_QtBluetooth[11807]
#define sipNameNr_AudioService 11821
#define sipName_AudioService &sipStrings_QtBluetooth[11821]
#define sipNameNr_BatteryLevel 11834
#define sipName_BatteryLevel &sipStrings_QtBluetooth[11834]
#define sipNameNr_Broadcasting 11847
#define sipName_Broadcasting &sipStrings_QtBluetooth[11847]
#define sipNameNr_ClosingState 11860
#define sipName_ClosingState &sipStrings_QtBluetooth[11860]
#define sipNameNr_CyclingPower 11873
#define sipName_CyclingPower &sipStrings_QtBluetooth[11873]
#define sipNameNr_EmailAddress 11886
#define sipName_EmailAddress &sipStrings_QtBluetooth[11886]
#define sipNameNr_ExactTime256 11899
#define sipName_ExactTime256 &sipStrings_QtBluetooth[11899]
#define sipNameNr_FilterPolicy 423
#define sipName_FilterPolicy &sipStrings_QtBluetooth[423]
#define sipNameNr_GamingDevice 11912
#define sipName_GamingDevice &sipStrings_QtBluetooth[11912]
#define sipNameNr_GenericAudio 11925
#define sipName_GenericAudio &sipStrings_QtBluetooth[11925]
#define sipNameNr_HealthDevice 4277
#define sipName_HealthDevice &sipStrings_QtBluetooth[4277]
#define sipNameNr_HeartRateMax 11938
#define sipName_HeartRateMax &sipStrings_QtBluetooth[11938]
#define sipNameNr_ImageDisplay 11951
#define sipName_ImageDisplay &sipStrings_QtBluetooth[11951]
#define sipNameNr_ImagePrinter 11964
#define sipName_ImagePrinter &sipStrings_QtBluetooth[11964]
#define sipNameNr_ImageScanner 11977
#define sipName_ImageScanner &sipStrings_QtBluetooth[11977]
#define sipNameNr_LocalService 11990
#define sipName_LocalService &sipStrings_QtBluetooth[11990]
#define sipNameNr_NetworkError 12003
#define sipName_NetworkError &sipStrings_QtBluetooth[12003]
#define sipNameNr_PairingError 12016
#define sipName_PairingError &sipStrings_QtBluetooth[12016]
#define sipNameNr_PropertyType 1157
#define sipName_PropertyType &sipStrings_QtBluetooth[1157]
#define sipNameNr_ProtocolMode 12029
#define sipName_ProtocolMode &sipStrings_QtBluetooth[12029]
#define sipNameNr_ProtocolUuid 3135
#define sipName_ProtocolUuid &sipStrings_QtBluetooth[3135]
#define sipNameNr_ServiceClass 1714
#define sipName_ServiceClass &sipStrings_QtBluetooth[1714]
#define sipNameNr_ServiceError 2440
#define sipName_ServiceError &sipStrings_QtBluetooth[2440]
#define sipNameNr_ServiceState 2472
#define sipName_ServiceState &sipStrings_QtBluetooth[2472]
#define sipNameNr_TimeAccuracy 12042
#define sipName_TimeAccuracy &sipStrings_QtBluetooth[12042]
#define sipNameNr_TxPowerLevel 12055
#define sipName_TxPowerLevel &sipStrings_QtBluetooth[12055]
#define sipNameNr_UnknownError 12068
#define sipName_UnknownError &sipStrings_QtBluetooth[12068]
#define sipNameNr_VideoMonitor 12081
#define sipName_VideoMonitor &sipStrings_QtBluetooth[12081]
#define sipNameNr_bytesToWrite 12094
#define sipName_bytesToWrite &sipStrings_QtBluetooth[12094]
#define sipNameNr_disconnected 12107
#define sipName_disconnected &sipStrings_QtBluetooth[12107]
#define sipNameNr_filterPolicy 12120
#define sipName_filterPolicy &sipStrings_QtBluetooth[12120]
#define sipNameNr_isRegistered 12133
#define sipName_isRegistered &sipStrings_QtBluetooth[12133]
#define sipNameNr_isSequential 12146
#define sipName_isSequential &sipStrings_QtBluetooth[12146]
#define sipNameNr_localAdapter 12159
#define sipName_localAdapter &sipStrings_QtBluetooth[12159]
#define sipNameNr_localAddress 12172
#define sipName_localAddress &sipStrings_QtBluetooth[12172]
#define sipNameNr_readLineData 12185
#define sipName_readLineData &sipStrings_QtBluetooth[12185]
#define sipNameNr_serviceUuids 12198
#define sipName_serviceUuids &sipStrings_QtBluetooth[12198]
#define sipNameNr_setAttribute 12211
#define sipName_setAttribute &sipStrings_QtBluetooth[12211]
#define sipNameNr_setLocalName 12224
#define sipName_setLocalName &sipStrings_QtBluetooth[12224]
#define sipNameNr_setWhiteList 12237
#define sipName_setWhiteList &sipStrings_QtBluetooth[12237]
#define sipNameNr_stateChanged 12250
#define sipName_stateChanged &sipStrings_QtBluetooth[12250]
#define sipNameNr_AddressInfo 469
#define sipName_AddressInfo &sipStrings_QtBluetooth[469]
#define sipNameNr_AlertStatus 8911
#define sipName_AlertStatus &sipStrings_QtBluetooth[8911]
#define sipNameNr_AllServices 12263
#define sipName_AllServices &sipStrings_QtBluetooth[12263]
#define sipNameNr_AttributeId 1750
#define sipName_AttributeId &sipStrings_QtBluetooth[1750]
#define sipNameNr_AudioSource 12275
#define sipName_AudioSource &sipStrings_QtBluetooth[12275]
#define sipNameNr_CCCDDisable 12287
#define sipName_CCCDDisable &sipStrings_QtBluetooth[12287]
#define sipNameNr_CentralRole 12299
#define sipName_CentralRole &sipStrings_QtBluetooth[12299]
#define sipNameNr_CurrentTime 12311
#define sipName_CurrentTime &sipStrings_QtBluetooth[12311]
#define sipNameNr_DateOfBirth 12323
#define sipName_DateOfBirth &sipStrings_QtBluetooth[12323]
#define sipNameNr_DayDateTime 12335
#define sipName_DayDateTime &sipStrings_QtBluetooth[12335]
#define sipNameNr_ImageCamera 12347
#define sipName_ImageCamera &sipStrings_QtBluetooth[12347]
#define sipNameNr_Loudspeaker 3913
#define sipName_Loudspeaker &sipStrings_QtBluetooth[3913]
#define sipNameNr_PhoneDevice 12359
#define sipName_PhoneDevice &sipStrings_QtBluetooth[12359]
#define sipNameNr_ReflectedUI 12371
#define sipName_ReflectedUI &sipStrings_QtBluetooth[12371]
#define sipNameNr_ScanRefresh 12383
#define sipName_ScanRefresh &sipStrings_QtBluetooth[12383]
#define sipNameNr_ServiceData 6242
#define sipName_ServiceData &sipStrings_QtBluetooth[6242]
#define sipNameNr_ServiceName 11272
#define sipName_ServiceName &sipStrings_QtBluetooth[11272]
#define sipNameNr_ServiceType 1820
#define sipName_ServiceType &sipStrings_QtBluetooth[1820]
#define sipNameNr_SocketError 2871
#define sipName_SocketError &sipStrings_QtBluetooth[2871]
#define sipNameNr_SocketState 2901
#define sipName_SocketState &sipStrings_QtBluetooth[2901]
#define sipNameNr_Temperature 5122
#define sipName_Temperature &sipStrings_QtBluetooth[5122]
#define sipNameNr_TimeWithDST 12395
#define sipName_TimeWithDST &sipStrings_QtBluetooth[12395]
#define sipNameNr_VideoCamera 12407
#define sipName_VideoCamera &sipStrings_QtBluetooth[12407]
#define sipNameNr_VideoSource 12419
#define sipName_VideoSource &sipStrings_QtBluetooth[12419]
#define sipNameNr_WeightScale 8695
#define sipName_WeightScale &sipStrings_QtBluetooth[8695]
#define sipNameNr_WriteSigned 12431
#define sipName_WriteSigned &sipStrings_QtBluetooth[12431]
#define sipNameNr_canReadLine 12443
#define sipName_canReadLine &sipStrings_QtBluetooth[12443]
#define sipNameNr_constraints 12455
#define sipName_constraints &sipStrings_QtBluetooth[12455]
#define sipNameNr_customEvent 12467
#define sipName_customEvent &sipStrings_QtBluetooth[12467]
#define sipNameNr_descriptors 12479
#define sipName_descriptors &sipStrings_QtBluetooth[12479]
#define sipNameNr_errorString 12491
#define sipName_errorString &sipStrings_QtBluetooth[12491]
#define sipNameNr_eventFilter 12503
#define sipName_eventFilter &sipStrings_QtBluetooth[12503]
#define sipNameNr_isListening 12515
#define sipName_isListening &sipStrings_QtBluetooth[12515]
#define sipNameNr_minimumSize 12527
#define sipName_minimumSize &sipStrings_QtBluetooth[12527]
#define sipNameNr_peerAddress 12539
#define sipName_peerAddress &sipStrings_QtBluetooth[12539]
#define sipNameNr_serviceData 12551
#define sipName_serviceData &sipStrings_QtBluetooth[12551]
#define sipNameNr_serviceName 12563
#define sipName_serviceName &sipStrings_QtBluetooth[12563]
#define sipNameNr_serviceUuid 12575
#define sipName_serviceUuid &sipStrings_QtBluetooth[12575]
#define sipNameNr_setHostMode 12587
#define sipName_setHostMode &sipStrings_QtBluetooth[12587]
#define sipNameNr_setInterval 12599
#define sipName_setInterval &sipStrings_QtBluetooth[12599]
#define sipNameNr_setServices 12611
#define sipName_setServices &sipStrings_QtBluetooth[12611]
#define sipNameNr_AdvScanInd 12623
#define sipName_AdvScanInd &sipStrings_QtBluetooth[12623]
#define sipNameNr_AlertLevel 12634
#define sipName_AlertLevel &sipStrings_QtBluetooth[12634]
#define sipNameNr_Appearance 12645
#define sipName_Appearance &sipStrings_QtBluetooth[12645]
#define sipNameNr_BasicImage 12656
#define sipName_BasicImage &sipStrings_QtBluetooth[12656]
#define sipNameNr_BoundState 12667
#define sipName_BoundState &sipStrings_QtBluetooth[12667]
#define sipNameNr_CSCFeature 12678
#define sipName_CSCFeature &sipStrings_QtBluetooth[12678]
#define sipNameNr_DeviceName 12689
#define sipName_DeviceName &sipStrings_QtBluetooth[12689]
#define sipNameNr_Encryption 12700
#define sipName_Encryption &sipStrings_QtBluetooth[12700]
#define sipNameNr_GNSSServer 12711
#define sipName_GNSSServer &sipStrings_QtBluetooth[12711]
#define sipNameNr_GustFactor 12722
#define sipName_GustFactor &sipStrings_QtBluetooth[12722]
#define sipNameNr_Headphones 12733
#define sipName_Headphones &sipStrings_QtBluetooth[12733]
#define sipNameNr_Irradiance 12744
#define sipName_Irradiance &sipStrings_QtBluetooth[12744]
#define sipNameNr_MPSProfile 12755
#define sipName_MPSProfile &sipStrings_QtBluetooth[12755]
#define sipNameNr_MPSService 12766
#define sipName_MPSService &sipStrings_QtBluetooth[12766]
#define sipNameNr_Microphone 12777
#define sipName_Microphone &sipStrings_QtBluetooth[12777]
#define sipNameNr_Navigation 6023
#define sipName_Navigation &sipStrings_QtBluetooth[6023]
#define sipNameNr_NoSecurity 12788
#define sipName_NoSecurity &sipStrings_QtBluetooth[12788]
#define sipNameNr_QBluetooth 12799
#define sipName_QBluetooth &sipStrings_QtBluetooth[12799]
#define sipNameNr_RSCFeature 12810
#define sipName_RSCFeature &sipStrings_QtBluetooth[12810]
#define sipNameNr_SerialPort 12821
#define sipName_SerialPort &sipStrings_QtBluetooth[12821]
#define sipNameNr_SmartPhone 12832
#define sipName_SmartPhone &sipStrings_QtBluetooth[12832]
#define sipNameNr_TimeSource 12843
#define sipName_TimeSource &sipStrings_QtBluetooth[12843]
#define sipNameNr_ToyVehicle 12854
#define sipName_ToyVehicle &sipStrings_QtBluetooth[12854]
#define sipNameNr_ValidRange 12865
#define sipName_ValidRange &sipStrings_QtBluetooth[12865]
#define sipNameNr___lshift__ 12876
#define sipName___lshift__ &sipStrings_QtBluetooth[12876]
#define sipNameNr___rshift__ 12887
#define sipName___rshift__ &sipStrings_QtBluetooth[12887]
#define sipNameNr_addService 12898
#define sipName_addService &sipStrings_QtBluetooth[12898]
#define sipNameNr_allDevices 12909
#define sipName_allDevices &sipStrings_QtBluetooth[12909]
#define sipNameNr_attributes 12920
#define sipName_attributes &sipStrings_QtBluetooth[12920]
#define sipNameNr_childEvent 12931
#define sipName_childEvent &sipStrings_QtBluetooth[12931]
#define sipNameNr_descriptor 12942
#define sipName_descriptor &sipStrings_QtBluetooth[12942]
#define sipNameNr_deviceUuid 12953
#define sipName_deviceUuid &sipStrings_QtBluetooth[12953]
#define sipNameNr_isComplete 12964
#define sipName_isComplete &sipStrings_QtBluetooth[12964]
#define sipNameNr_isReadable 12975
#define sipName_isReadable &sipStrings_QtBluetooth[12975]
#define sipNameNr_isWritable 12986
#define sipName_isWritable &sipStrings_QtBluetooth[12986]
#define sipNameNr_mtuChanged 12997
#define sipName_mtuChanged &sipStrings_QtBluetooth[12997]
#define sipNameNr_properties 13008
#define sipName_properties &sipStrings_QtBluetooth[13008]
#define sipNameNr_remoteName 13019
#define sipName_remoteName &sipStrings_QtBluetooth[13019]
#define sipNameNr_serverPort 13030
#define sipName_serverPort &sipStrings_QtBluetooth[13030]
#define sipNameNr_serverType 13041
#define sipName_serverType &sipStrings_QtBluetooth[13041]
#define sipNameNr_serviceIds 13052
#define sipName_serviceIds &sipStrings_QtBluetooth[13052]
#define sipNameNr_setAddress 13063
#define sipName_setAddress &sipStrings_QtBluetooth[13063]
#define sipNameNr_setLatency 13074
#define sipName_setLatency &sipStrings_QtBluetooth[13074]
#define sipNameNr_setRawData 13085
#define sipName_setRawData &sipStrings_QtBluetooth[13085]
#define sipNameNr_socketType 13096
#define sipName_socketType &sipStrings_QtBluetooth[13096]
#define sipNameNr_timerEvent 13107
#define sipName_timerEvent &sipStrings_QtBluetooth[13107]
#define sipNameNr_uuidFilter 13118
#define sipName_uuidFilter &sipStrings_QtBluetooth[13118]
#define sipNameNr_AudioSink 13129
#define sipName_AudioSink &sipStrings_QtBluetooth[13129]
#define sipNameNr_Camcorder 13139
#define sipName_Camcorder &sipStrings_QtBluetooth[13139]
#define sipNameNr_DSTOffset 13149
#define sipName_DSTOffset &sipStrings_QtBluetooth[13149]
#define sipNameNr_DayOfWeek 13159
#define sipName_DayOfWeek &sipStrings_QtBluetooth[13159]
#define sipNameNr_Display3D 13169
#define sipName_Display3D &sipStrings_QtBluetooth[13169]
#define sipNameNr_Elevation 13179
#define sipName_Elevation &sipStrings_QtBluetooth[13179]
#define sipNameNr_FirstName 13189
#define sipName_FirstName &sipStrings_QtBluetooth[13189]
#define sipNameNr_Glasses3D 13199
#define sipName_Glasses3D &sipStrings_QtBluetooth[13199]
#define sipNameNr_HDPSource 13209
#define sipName_HDPSource &sipStrings_QtBluetooth[13209]
#define sipNameNr_Handsfree 13219
#define sipName_Handsfree &sipStrings_QtBluetooth[13219]
#define sipNameNr_HeadsetAG 13229
#define sipName_HeadsetAG &sipStrings_QtBluetooth[13229]
#define sipNameNr_HeadsetHS 13239
#define sipName_HeadsetHS &sipStrings_QtBluetooth[13239]
#define sipNameNr_HeartRate 3424
#define sipName_HeartRate &sipStrings_QtBluetooth[3424]
#define sipNameNr_HeatIndex 13249
#define sipName_HeatIndex &sipStrings_QtBluetooth[13249]
#define sipNameNr_LNFeature 13259
#define sipName_LNFeature &sipStrings_QtBluetooth[13259]
#define sipNameNr_NoService 9523
#define sipName_NoService &sipStrings_QtBluetooth[9523]
#define sipNameNr_ReportMap 13269
#define sipName_ReportMap &sipStrings_QtBluetooth[13269]
#define sipNameNr_SIMAccess 13279
#define sipName_SIMAccess &sipStrings_QtBluetooth[13279]
#define sipNameNr_ServiceId 13289
#define sipName_ServiceId &sipStrings_QtBluetooth[13289]
#define sipNameNr_SetTopBox 13299
#define sipName_SetTopBox &sipStrings_QtBluetooth[13299]
#define sipNameNr_ToyDevice 13309
#define sipName_ToyDevice &sipStrings_QtBluetooth[13309]
#define sipNameNr_UdiCPlain 13319
#define sipName_UdiCPlain &sipStrings_QtBluetooth[13319]
#define sipNameNr_UserIndex 13329
#define sipName_UserIndex &sipStrings_QtBluetooth[13329]
#define sipNameNr_VideoSink 13339
#define sipName_VideoSink &sipStrings_QtBluetooth[13339]
#define sipNameNr_WindChill 13349
#define sipName_WindChill &sipStrings_QtBluetooth[13349]
#define sipNameNr_WriteMode 3254
#define sipName_WriteMode &sipStrings_QtBluetooth[3254]
#define sipNameNr_attribute 13359
#define sipName_attribute &sipStrings_QtBluetooth[13359]
#define sipNameNr_connected 8307
#define sipName_connected &sipStrings_QtBluetooth[8307]
#define sipNameNr_localName 13369
#define sipName_localName &sipStrings_QtBluetooth[13369]
#define sipNameNr_localPort 13379
#define sipName_localPort &sipStrings_QtBluetooth[13379]
#define sipNameNr_setCached 13389
#define sipName_setCached &sipStrings_QtBluetooth[13389]
#define sipNameNr_setDevice 6354
#define sipName_setDevice &sipStrings_QtBluetooth[6354]
#define sipNameNr_toUInt128 13399
#define sipName_toUInt128 &sipStrings_QtBluetooth[13399]
#define sipNameNr_whiteList 13409
#define sipName_whiteList &sipStrings_QtBluetooth[13409]
#define sipNameNr_writeData 13419
#define sipName_writeData &sipStrings_QtBluetooth[13419]
#define sipNameNr_CarAudio 13429
#define sipName_CarAudio &sipStrings_QtBluetooth[13429]
#define sipNameNr_DateTime 12338
#define sipName_DateTime &sipStrings_QtBluetooth[12338]
#define sipNameNr_DewPoint 13438
#define sipName_DewPoint &sipStrings_QtBluetooth[13438]
#define sipNameNr_HCRPrint 13447
#define sipName_HCRPrint &sipStrings_QtBluetooth[13447]
#define sipNameNr_HostMode 2220
#define sipName_HostMode &sipStrings_QtBluetooth[2220]
#define sipNameNr_Humidity 13456
#define sipName_Humidity &sipStrings_QtBluetooth[13456]
#define sipNameNr_Indicate 13465
#define sipName_Indicate &sipStrings_QtBluetooth[13465]
#define sipNameNr_IrMCSync 13474
#define sipName_IrMCSync &sipStrings_QtBluetooth[13474]
#define sipNameNr_Language 13483
#define sipName_Language &sipStrings_QtBluetooth[13483]
#define sipNameNr_LastName 13492
#define sipName_LastName &sipStrings_QtBluetooth[13492]
#define sipNameNr_LinkLoss 13501
#define sipName_LinkLoss &sipStrings_QtBluetooth[13501]
#define sipNameNr_NewAlert 13510
#define sipName_NewAlert &sipStrings_QtBluetooth[13510]
#define sipNameNr_NoMethod 13519
#define sipName_NoMethod &sipStrings_QtBluetooth[13519]
#define sipNameNr_Pressure 4585
#define sipName_Pressure &sipStrings_QtBluetooth[4585]
#define sipNameNr_Protocol 2284
#define sipName_Protocol &sipStrings_QtBluetooth[2284]
#define sipNameNr_Rainfall 13528
#define sipName_Rainfall &sipStrings_QtBluetooth[13528]
#define sipNameNr_Security 6911
#define sipName_Security &sipStrings_QtBluetooth[6911]
#define sipNameNr_Sequence 2316
#define sipName_Sequence &sipStrings_QtBluetooth[2316]
#define sipNameNr_SystemID 13537
#define sipName_SystemID &sipStrings_QtBluetooth[13537]
#define sipNameNr_TimeZone 13546
#define sipName_TimeZone &sipStrings_QtBluetooth[13546]
#define sipNameNr_ToyRobot 13555
#define sipName_ToyRobot &sipStrings_QtBluetooth[13555]
#define sipNameNr_Unpaired 13564
#define sipName_Unpaired &sipStrings_QtBluetooth[13564]
#define sipNameNr_UserData 13573
#define sipName_UserData &sipStrings_QtBluetooth[13573]
#define sipNameNr___hash__ 13582
#define sipName___hash__ &sipStrings_QtBluetooth[13582]
#define sipNameNr_canceled 13591
#define sipName_canceled &sipStrings_QtBluetooth[13591]
#define sipNameNr_contains 13600
#define sipName_contains &sipStrings_QtBluetooth[13600]
#define sipNameNr_finished 13609
#define sipName_finished &sipStrings_QtBluetooth[13609]
#define sipNameNr_hostMode 13618
#define sipName_hostMode &sipStrings_QtBluetooth[13618]
#define sipNameNr_isActive 13627
#define sipName_isActive &sipStrings_QtBluetooth[13627]
#define sipNameNr_isCached 13636
#define sipName_isCached &sipStrings_QtBluetooth[13636]
#define sipNameNr_peerName 13645
#define sipName_peerName &sipStrings_QtBluetooth[13645]
#define sipNameNr_peerPort 13654
#define sipName_peerPort &sipStrings_QtBluetooth[13654]
#define sipNameNr_quint128 13663
#define sipName_quint128 &sipStrings_QtBluetooth[13663]
#define sipNameNr_readData 13672
#define sipName_readData &sipStrings_QtBluetooth[13672]
#define sipNameNr_readRssi 13681
#define sipName_readRssi &sipStrings_QtBluetooth[13681]
#define sipNameNr_rssiRead 13690
#define sipName_rssiRead &sipStrings_QtBluetooth[13690]
#define sipNameNr_services 13699
#define sipName_services &sipStrings_QtBluetooth[13699]
#define sipNameNr_setValue 13708
#define sipName_setValue &sipStrings_QtBluetooth[13708]
#define sipNameNr_skipData 13717
#define sipName_skipData &sipStrings_QtBluetooth[13717]
#define sipNameNr_toString 13726
#define sipName_toString &sipStrings_QtBluetooth[13726]
#define sipNameNr_toUInt16 13735
#define sipName_toUInt16 &sipStrings_QtBluetooth[13735]
#define sipNameNr_toUInt32 13744
#define sipName_toUInt32 &sipStrings_QtBluetooth[13744]
#define sipNameNr_toUInt64 13753
#define sipName_toUInt64 &sipStrings_QtBluetooth[13753]
#define sipNameNr_Glucose 13762
#define sipName_Glucose &sipStrings_QtBluetooth[13762]
#define sipNameNr_HCRScan 13770
#define sipName_HCRScan &sipStrings_QtBluetooth[13770]
#define sipNameNr_HDPSink 13778
#define sipName_HDPSink &sipStrings_QtBluetooth[13778]
#define sipNameNr_Headset 13786
#define sipName_Headset &sipStrings_QtBluetooth[13786]
#define sipNameNr_IconUrl 13794
#define sipName_IconUrl &sipStrings_QtBluetooth[13794]
#define sipNameNr_NoError 13802
#define sipName_NoError &sipStrings_QtBluetooth[13802]
#define sipNameNr_Pairing 2601
#define sipName_Pairing &sipStrings_QtBluetooth[2601]
#define sipNameNr_ToyDoll 13810
#define sipName_ToyDoll &sipStrings_QtBluetooth[13810]
#define sipNameNr_ToyGame 13818
#define sipName_ToyGame &sipStrings_QtBluetooth[13818]
#define sipNameNr_TxPower 13826
#define sipName_TxPower &sipStrings_QtBluetooth[13826]
#define sipNameNr_UVIndex 13834
#define sipName_UVIndex &sipStrings_QtBluetooth[13834]
#define sipNameNr_Unknown 13842
#define sipName_Unknown &sipStrings_QtBluetooth[13842]
#define sipNameNr_address 13850
#define sipName_address &sipStrings_QtBluetooth[13850]
#define sipNameNr_isValid 13858
#define sipName_isValid &sipStrings_QtBluetooth[13858]
#define sipNameNr_latency 13866
#define sipName_latency &sipStrings_QtBluetooth[13866]
#define sipNameNr_powerOn 13874
#define sipName_powerOn &sipStrings_QtBluetooth[13874]
#define sipNameNr_rawData 13882
#define sipName_rawData &sipStrings_QtBluetooth[13882]
#define sipNameNr_setMode 13890
#define sipName_setMode &sipStrings_QtBluetooth[13890]
#define sipNameNr_setName 13898
#define sipName_setName &sipStrings_QtBluetooth[13898]
#define sipNameNr_setRssi 13906
#define sipName_setRssi &sipStrings_QtBluetooth[13906]
#define sipNameNr_setType 13914
#define sipName_setType &sipStrings_QtBluetooth[13914]
#define sipNameNr_setUuid 13922
#define sipName_setUuid &sipStrings_QtBluetooth[13922]
#define sipNameNr_AdvInd 13930
#define sipName_AdvInd &sipStrings_QtBluetooth[13930]
#define sipNameNr_Gender 13937
#define sipName_Gender &sipStrings_QtBluetooth[13937]
#define sipNameNr_Height 13944
#define sipName_Height &sipStrings_QtBluetooth[13944]
#define sipNameNr_Notify 9798
#define sipName_Notify &sipStrings_QtBluetooth[9798]
#define sipNameNr_Paired 9271
#define sipName_Paired &sipStrings_QtBluetooth[9271]
#define sipNameNr_Report 4487
#define sipName_Report &sipStrings_QtBluetooth[4487]
#define sipNameNr_Rfcomm 13951
#define sipName_Rfcomm &sipStrings_QtBluetooth[13951]
#define sipNameNr_Secure 13958
#define sipName_Secure &sipStrings_QtBluetooth[13958]
#define sipNameNr_TcsBin 13965
#define sipName_TcsBin &sipStrings_QtBluetooth[13965]
#define sipNameNr_VO2Max 13972
#define sipName_VO2Max &sipStrings_QtBluetooth[13972]
#define sipNameNr_Weight 13979
#define sipName_Weight &sipStrings_QtBluetooth[13979]
#define sipNameNr___eq__ 13986
#define sipName___eq__ &sipStrings_QtBluetooth[13986]
#define sipNameNr___ge__ 13993
#define sipName___ge__ &sipStrings_QtBluetooth[13993]
#define sipNameNr___lt__ 14000
#define sipName___lt__ &sipStrings_QtBluetooth[14000]
#define sipNameNr___ne__ 14007
#define sipName___ne__ &sipStrings_QtBluetooth[14007]
#define sipNameNr_device 14014
#define sipName_device &sipStrings_QtBluetooth[14014]
#define sipNameNr_isNull 14021
#define sipName_isNull &sipStrings_QtBluetooth[14021]
#define sipNameNr_listen 14028
#define sipName_listen &sipStrings_QtBluetooth[14028]
#define sipNameNr_parent 14035
#define sipName_parent &sipStrings_QtBluetooth[14035]
#define sipNameNr_Avctp 14042
#define sipName_Avctp &sipStrings_QtBluetooth[14042]
#define sipNameNr_Avdtp 14048
#define sipName_Avdtp &sipStrings_QtBluetooth[14048]
#define sipNameNr_Error 1086
#define sipName_Error &sipStrings_QtBluetooth[1086]
#define sipNameNr_Field 3456
#define sipName_Field &sipStrings_QtBluetooth[3456]
#define sipNameNr_L2cap 14054
#define sipName_L2cap &sipStrings_QtBluetooth[14054]
#define sipNameNr_None_ 14060
#define sipName_None_ &sipStrings_QtBluetooth[14060]
#define sipNameNr_PnPID 14066
#define sipName_PnPID &sipStrings_QtBluetooth[14066]
#define sipNameNr_TcsAt 14072
#define sipName_TcsAt &sipStrings_QtBluetooth[14072]
#define sipNameNr_Write 12101
#define sipName_Write &sipStrings_QtBluetooth[12101]
#define sipNameNr_abort 14078
#define sipName_abort &sipStrings_QtBluetooth[14078]
#define sipNameNr_atEnd 14084
#define sipName_atEnd &sipStrings_QtBluetooth[14084]
#define sipNameNr_clear 14090
#define sipName_clear &sipStrings_QtBluetooth[14090]
#define sipNameNr_close 14096
#define sipName_close &sipStrings_QtBluetooth[14096]
#define sipNameNr_error 14102
#define sipName_error &sipStrings_QtBluetooth[14102]
#define sipNameNr_event 14108
#define sipName_event &sipStrings_QtBluetooth[14108]
#define sipNameNr_order 13143
#define sipName_order &sipStrings_QtBluetooth[13143]
#define sipNameNr_reset 14114
#define sipName_reset &sipStrings_QtBluetooth[14114]
#define sipNameNr_start 14120
#define sipName_start &sipStrings_QtBluetooth[14120]
#define sipNameNr_state 14126
#define sipName_state &sipStrings_QtBluetooth[14126]
#define sipNameNr_value 14132
#define sipName_value &sipStrings_QtBluetooth[14132]
#define sipNameNr_Bnep 14138
#define sipName_Bnep &sipStrings_QtBluetooth[14138]
#define sipNameNr_Cmtp 14143
#define sipName_Cmtp &sipStrings_QtBluetooth[14143]
#define sipNameNr_GNSS 14148
#define sipName_GNSS &sipStrings_QtBluetooth[14148]
#define sipNameNr_Hidp 14153
#define sipName_Hidp &sipStrings_QtBluetooth[14153]
#define sipNameNr_Http 14158
#define sipName_Http &sipStrings_QtBluetooth[14158]
#define sipNameNr_Mode 246
#define sipName_Mode &sipStrings_QtBluetooth[246]
#define sipNameNr_Obex 14163
#define sipName_Obex &sipStrings_QtBluetooth[14163]
#define sipNameNr_PANU 14168
#define sipName_PANU &sipStrings_QtBluetooth[14168]
#define sipNameNr_RSSI 14173
#define sipName_RSSI &sipStrings_QtBluetooth[14173]
#define sipNameNr_Read 8255
#define sipName_Read &sipStrings_QtBluetooth[8255]
#define sipNameNr_Role 3785
#define sipName_Role &sipStrings_QtBluetooth[3785]
#define sipNameNr_Upnp 14178
#define sipName_Upnp &sipStrings_QtBluetooth[14178]
#define sipNameNr_mode 14183
#define sipName_mode &sipStrings_QtBluetooth[14183]
#define sipNameNr_name 14188
#define sipName_name &sipStrings_QtBluetooth[14188]
#define sipNameNr_open 14193
#define sipName_open &sipStrings_QtBluetooth[14193]
#define sipNameNr_port 4489
#define sipName_port &sipStrings_QtBluetooth[4489]
#define sipNameNr_role 14198
#define sipName_role &sipStrings_QtBluetooth[14198]
#define sipNameNr_rssi 14203
#define sipName_rssi &sipStrings_QtBluetooth[14203]
#define sipNameNr_seek 14208
#define sipName_seek &sipStrings_QtBluetooth[14208]
#define sipNameNr_size 14213
#define sipName_size &sipStrings_QtBluetooth[14213]
#define sipNameNr_stop 14218
#define sipName_stop &sipStrings_QtBluetooth[14218]
#define sipNameNr_swap 14223
#define sipName_swap &sipStrings_QtBluetooth[14223]
#define sipNameNr_type 14228
#define sipName_type &sipStrings_QtBluetooth[14228]
#define sipNameNr_uuid 14233
#define sipName_uuid &sipStrings_QtBluetooth[14233]
#define sipNameNr_Age 14238
#define sipName_Age &sipStrings_QtBluetooth[14238]
#define sipNameNr_All 14242
#define sipName_All &sipStrings_QtBluetooth[14242]
#define sipNameNr_Att 14246
#define sipName_Att &sipStrings_QtBluetooth[14246]
#define sipNameNr_Ftp 14250
#define sipName_Ftp &sipStrings_QtBluetooth[14250]
#define sipNameNr_HDP 14254
#define sipName_HDP &sipStrings_QtBluetooth[14254]
#define sipNameNr_NAP 14258
#define sipName_NAP &sipStrings_QtBluetooth[14258]
#define sipNameNr_Sdp 14262
#define sipName_Sdp &sipStrings_QtBluetooth[14262]
#define sipNameNr_Tcp 14266
#define sipName_Tcp &sipStrings_QtBluetooth[14266]
#define sipNameNr_Udp 14270
#define sipName_Udp &sipStrings_QtBluetooth[14270]
#define sipNameNr_Vcr 14274
#define sipName_Vcr &sipStrings_QtBluetooth[14274]
#define sipNameNr_Wsp 14278
#define sipName_Wsp &sipStrings_QtBluetooth[14278]
#define sipNameNr_mtu 14282
#define sipName_mtu &sipStrings_QtBluetooth[14282]
#define sipNameNr_pos 14286
#define sipName_pos &sipStrings_QtBluetooth[14286]
#define sipNameNr_GN 14290
#define sipName_GN &sipStrings_QtBluetooth[14290]
#define sipNameNr_Ip 14293
#define sipName_Ip &sipStrings_QtBluetooth[14293]
#define sipNameNr_ok 14296
#define sipName_ok &sipStrings_QtBluetooth[14296]

#define sipMalloc                   sipAPI_QtBluetooth->api_malloc
#define sipFree                     sipAPI_QtBluetooth->api_free
#define sipBuildResult              sipAPI_QtBluetooth->api_build_result
#define sipCallMethod               sipAPI_QtBluetooth->api_call_method
#define sipCallProcedureMethod      sipAPI_QtBluetooth->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtBluetooth->api_call_error_handler
#define sipParseResultEx            sipAPI_QtBluetooth->api_parse_result_ex
#define sipParseResult              sipAPI_QtBluetooth->api_parse_result
#define sipParseArgs                sipAPI_QtBluetooth->api_parse_args
#define sipParseKwdArgs             sipAPI_QtBluetooth->api_parse_kwd_args
#define sipParsePair                sipAPI_QtBluetooth->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtBluetooth->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtBluetooth->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtBluetooth->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtBluetooth->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtBluetooth->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtBluetooth->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtBluetooth->api_add_exception
#define sipNoFunction               sipAPI_QtBluetooth->api_no_function
#define sipNoMethod                 sipAPI_QtBluetooth->api_no_method
#define sipAbstractMethod           sipAPI_QtBluetooth->api_abstract_method
#define sipBadClass                 sipAPI_QtBluetooth->api_bad_class
#define sipBadCatcherResult         sipAPI_QtBluetooth->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtBluetooth->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtBluetooth->api_bad_operator_arg
#define sipTrace                    sipAPI_QtBluetooth->api_trace
#define sipTransferBack             sipAPI_QtBluetooth->api_transfer_back
#define sipTransferTo               sipAPI_QtBluetooth->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtBluetooth->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtBluetooth->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtBluetooth->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtBluetooth->api_voidptr_type
#define sipGetPyObject              sipAPI_QtBluetooth->api_get_pyobject
#define sipGetAddress               sipAPI_QtBluetooth->api_get_address
#define sipGetMixinAddress          sipAPI_QtBluetooth->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtBluetooth->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtBluetooth->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtBluetooth->api_call_hook
#define sipEndThread                sipAPI_QtBluetooth->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtBluetooth->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtBluetooth->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtBluetooth->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtBluetooth->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtBluetooth->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtBluetooth->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtBluetooth->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtBluetooth->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtBluetooth->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtBluetooth->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtBluetooth->api_convert_to_bool
#define sipReleaseType              sipAPI_QtBluetooth->api_release_type
#define sipConvertFromType          sipAPI_QtBluetooth->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtBluetooth->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtBluetooth->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtBluetooth->api_convert_from_enum
#define sipGetState                 sipAPI_QtBluetooth->api_get_state
#define sipExportSymbol             sipAPI_QtBluetooth->api_export_symbol
#define sipImportSymbol             sipAPI_QtBluetooth->api_import_symbol
#define sipFindType                 sipAPI_QtBluetooth->api_find_type
#define sipBytes_AsChar             sipAPI_QtBluetooth->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtBluetooth->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtBluetooth->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtBluetooth->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtBluetooth->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtBluetooth->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtBluetooth->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtBluetooth->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtBluetooth->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtBluetooth->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtBluetooth->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtBluetooth->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtBluetooth->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtBluetooth->api_get_reference
#define sipKeepReference            sipAPI_QtBluetooth->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtBluetooth->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtBluetooth->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtBluetooth->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtBluetooth->api_type_scope
#define sipResolveTypedef           sipAPI_QtBluetooth->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtBluetooth->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtBluetooth->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtBluetooth->api_init_mixin
#define sipExportModule             sipAPI_QtBluetooth->api_export_module
#define sipInitModule               sipAPI_QtBluetooth->api_init_module
#define sipGetInterpreter           sipAPI_QtBluetooth->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtBluetooth->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtBluetooth->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtBluetooth->api_py_type_dict
#define sipPyTypeName               sipAPI_QtBluetooth->api_py_type_name
#define sipGetCFunction             sipAPI_QtBluetooth->api_get_c_function
#define sipGetMethod                sipAPI_QtBluetooth->api_get_method
#define sipFromMethod               sipAPI_QtBluetooth->api_from_method
#define sipGetDate                  sipAPI_QtBluetooth->api_get_date
#define sipFromDate                 sipAPI_QtBluetooth->api_from_date
#define sipGetDateTime              sipAPI_QtBluetooth->api_get_datetime
#define sipFromDateTime             sipAPI_QtBluetooth->api_from_datetime
#define sipGetTime                  sipAPI_QtBluetooth->api_get_time
#define sipFromTime                 sipAPI_QtBluetooth->api_from_time
#define sipIsUserType               sipAPI_QtBluetooth->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtBluetooth->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtBluetooth->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtBluetooth->api_unicode_write
#define sipUnicodeData              sipAPI_QtBluetooth->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtBluetooth->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtBluetooth->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtBluetooth->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtBluetooth->api_is_derived_class
#define sipGetUserObject            sipAPI_QtBluetooth->api_get_user_object
#define sipSetUserObject            sipAPI_QtBluetooth->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtBluetooth->api_register_event_handler
#define sipConvertToArray           sipAPI_QtBluetooth->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtBluetooth->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtBluetooth->api_enable_gc
#define sipPrintObject              sipAPI_QtBluetooth->api_print_object
#define sipLong_AsChar              sipAPI_QtBluetooth->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtBluetooth->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtBluetooth->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtBluetooth->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtBluetooth->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtBluetooth->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtBluetooth->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtBluetooth->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtBluetooth->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtBluetooth->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtBluetooth->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtBluetooth->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtBluetooth->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtBluetooth->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtBluetooth->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtBluetooth->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtBluetooth->api_next_exception_handler
#define sipIsEnumFlag               sipAPI_QtBluetooth->api_is_enum_flag
#define sipConvertToTypeUS          sipAPI_QtBluetooth->api_convert_to_type_us
#define sipForceConvertToTypeUS     sipAPI_QtBluetooth->api_force_convert_to_type_us
#define sipReleaseTypeUS            sipAPI_QtBluetooth->api_release_type_us
#define sipIsPyMethod               sipAPI_QtBluetooth->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtBluetooth[];

#define sipType_QBluetooth sipExportedTypes_QtBluetooth[0]

#define sipType_QBluetooth_AttAccessConstraint sipExportedTypes_QtBluetooth[1]

#define sipType_QBluetooth_Security sipExportedTypes_QtBluetooth[2]

extern sipClassTypeDef sipTypeDef_QtBluetooth_QBluetooth;

#define sipType_QBluetoothAddress sipExportedTypes_QtBluetooth[3]

extern sipClassTypeDef sipTypeDef_QtBluetooth_QBluetoothAddress;

#define sipType_QBluetoothDeviceDiscoveryAgent sipExportedTypes_QtBluetooth[4]

#define sipType_QBluetoothDeviceDiscoveryAgent_DiscoveryMethod sipExportedTypes_QtBluetooth[5]

#define sipType_QBluetoothDeviceDiscoveryAgent_Error sipExportedTypes_QtBluetooth[6]

extern sipClassTypeDef sipTypeDef_QtBluetooth_QBluetoothDeviceDiscoveryAgent;

#define sipType_QBluetoothDeviceInfo sipExportedTypes_QtBluetooth[7]

#define sipType_QBluetoothDeviceInfo_Field sipExportedTypes_QtBluetooth[9]

#define sipType_QBluetoothDeviceInfo_CoreConfiguration sipExportedTypes_QtBluetooth[8]

#define sipType_QBluetoothDeviceInfo_ServiceClass sipExportedTypes_QtBluetooth[21]

#define sipType_QBluetoothDeviceInfo_MinorHealthClass sipExportedTypes_QtBluetooth[13]

#define sipType_QBluetoothDeviceInfo_MinorToyClass sipExportedTypes_QtBluetooth[19]

#define sipType_QBluetoothDeviceInfo_MinorWearableClass sipExportedTypes_QtBluetooth[20]

#define sipType_QBluetoothDeviceInfo_MinorImagingClass sipExportedTypes_QtBluetooth[14]

#define sipType_QBluetoothDeviceInfo_MinorPeripheralClass sipExportedTypes_QtBluetooth[17]

#define sipType_QBluetoothDeviceInfo_MinorAudioVideoClass sipExportedTypes_QtBluetooth[11]

#define sipType_QBluetoothDeviceInfo_MinorNetworkClass sipExportedTypes_QtBluetooth[16]

#define sipType_QBluetoothDeviceInfo_MinorPhoneClass sipExportedTypes_QtBluetooth[18]

#define sipType_QBluetoothDeviceInfo_MinorComputerClass sipExportedTypes_QtBluetooth[12]

#define sipType_QBluetoothDeviceInfo_MinorMiscellaneousClass sipExportedTypes_QtBluetooth[15]

#define sipType_QBluetoothDeviceInfo_MajorDeviceClass sipExportedTypes_QtBluetooth[10]

extern sipClassTypeDef sipTypeDef_QtBluetooth_QBluetoothDeviceInfo;

#define sipType_QBluetoothHostInfo sipExportedTypes_QtBluetooth[22]

extern sipClassTypeDef sipTypeDef_QtBluetooth_QBluetoothHostInfo;

#define sipType_QBluetoothLocalDevice sipExportedTypes_QtBluetooth[23]

#define sipType_QBluetoothLocalDevice_Error sipExportedTypes_QtBluetooth[24]

#define sipType_QBluetoothLocalDevice_HostMode sipExportedTypes_QtBluetooth[25]

#define sipType_QBluetoothLocalDevice_Pairing sipExportedTypes_QtBluetooth[26]

extern sipClassTypeDef sipTypeDef_QtBluetooth_QBluetoothLocalDevice;

#define sipType_QBluetoothServer sipExportedTypes_QtBluetooth[27]

#define sipType_QBluetoothServer_Error sipExportedTypes_QtBluetooth[28]

extern sipClassTypeDef sipTypeDef_QtBluetooth_QBluetoothServer;

#define sipType_QBluetoothServiceDiscoveryAgent sipExportedTypes_QtBluetooth[29]

#define sipType_QBluetoothServiceDiscoveryAgent_DiscoveryMode sipExportedTypes_QtBluetooth[30]

#define sipType_QBluetoothServiceDiscoveryAgent_Error sipExportedTypes_QtBluetooth[31]

extern sipClassTypeDef sipTypeDef_QtBluetooth_QBluetoothServiceDiscoveryAgent;

#define sipType_QBluetoothServiceInfo sipExportedTypes_QtBluetooth[32]

#define sipType_QBluetoothServiceInfo_Protocol sipExportedTypes_QtBluetooth[34]

#define sipType_QBluetoothServiceInfo_AttributeId sipExportedTypes_QtBluetooth[33]

extern sipClassTypeDef sipTypeDef_QtBluetooth_QBluetoothServiceInfo;

#define sipType_QBluetoothSocket sipExportedTypes_QtBluetooth[36]

#define sipType_QBluetoothSocket_SocketError sipExportedTypes_QtBluetooth[37]

#define sipType_QBluetoothSocket_SocketState sipExportedTypes_QtBluetooth[38]

extern sipClassTypeDef sipTypeDef_QtBluetooth_QBluetoothSocket;

#define sipType_QBluetoothUuid sipExportedTypes_QtBluetooth[39]

#define sipType_QBluetoothUuid_DescriptorType sipExportedTypes_QtBluetooth[41]

#define sipType_QBluetoothUuid_CharacteristicType sipExportedTypes_QtBluetooth[40]

#define sipType_QBluetoothUuid_ServiceClassUuid sipExportedTypes_QtBluetooth[43]

#define sipType_QBluetoothUuid_ProtocolUuid sipExportedTypes_QtBluetooth[42]

extern sipClassTypeDef sipTypeDef_QtBluetooth_QBluetoothUuid;

#define sipType_QLowEnergyAdvertisingData sipExportedTypes_QtBluetooth[63]

#define sipType_QLowEnergyAdvertisingData_Discoverability sipExportedTypes_QtBluetooth[64]

extern sipClassTypeDef sipTypeDef_QtBluetooth_QLowEnergyAdvertisingData;

#define sipType_QLowEnergyAdvertisingParameters sipExportedTypes_QtBluetooth[65]

#define sipType_QLowEnergyAdvertisingParameters_FilterPolicy sipExportedTypes_QtBluetooth[67]

#define sipType_QLowEnergyAdvertisingParameters_Mode sipExportedTypes_QtBluetooth[68]

extern sipClassTypeDef sipTypeDef_QtBluetooth_QLowEnergyAdvertisingParameters;

#define sipType_QLowEnergyAdvertisingParameters_AddressInfo sipExportedTypes_QtBluetooth[66]

extern sipClassTypeDef sipTypeDef_QtBluetooth_QLowEnergyAdvertisingParameters_AddressInfo;

#define sipType_QLowEnergyCharacteristic sipExportedTypes_QtBluetooth[69]

#define sipType_QLowEnergyCharacteristic_PropertyType sipExportedTypes_QtBluetooth[70]

extern sipClassTypeDef sipTypeDef_QtBluetooth_QLowEnergyCharacteristic;

#define sipType_QLowEnergyCharacteristicData sipExportedTypes_QtBluetooth[71]

extern sipClassTypeDef sipTypeDef_QtBluetooth_QLowEnergyCharacteristicData;

#define sipType_QLowEnergyConnectionParameters sipExportedTypes_QtBluetooth[72]

extern sipClassTypeDef sipTypeDef_QtBluetooth_QLowEnergyConnectionParameters;

#define sipType_QLowEnergyController sipExportedTypes_QtBluetooth[73]

#define sipType_QLowEnergyController_Role sipExportedTypes_QtBluetooth[77]

#define sipType_QLowEnergyController_RemoteAddressType sipExportedTypes_QtBluetooth[76]

#define sipType_QLowEnergyController_ControllerState sipExportedTypes_QtBluetooth[74]

#define sipType_QLowEnergyController_Error sipExportedTypes_QtBluetooth[75]

extern sipClassTypeDef sipTypeDef_QtBluetooth_QLowEnergyController;

#define sipType_QLowEnergyDescriptor sipExportedTypes_QtBluetooth[78]

extern sipClassTypeDef sipTypeDef_QtBluetooth_QLowEnergyDescriptor;

#define sipType_QLowEnergyDescriptorData sipExportedTypes_QtBluetooth[79]

extern sipClassTypeDef sipTypeDef_QtBluetooth_QLowEnergyDescriptorData;

#define sipType_QLowEnergyService sipExportedTypes_QtBluetooth[80]

#define sipType_QLowEnergyService_WriteMode sipExportedTypes_QtBluetooth[85]

#define sipType_QLowEnergyService_ServiceState sipExportedTypes_QtBluetooth[83]

#define sipType_QLowEnergyService_ServiceError sipExportedTypes_QtBluetooth[82]

#define sipType_QLowEnergyService_ServiceType sipExportedTypes_QtBluetooth[84]

#define sipType_QLowEnergyService_DiscoveryMode sipExportedTypes_QtBluetooth[81]

extern sipClassTypeDef sipTypeDef_QtBluetooth_QLowEnergyService;

#define sipType_QLowEnergyServiceData sipExportedTypes_QtBluetooth[86]

#define sipType_QLowEnergyServiceData_ServiceType sipExportedTypes_QtBluetooth[87]

extern sipClassTypeDef sipTypeDef_QtBluetooth_QLowEnergyServiceData;

#define sipType_QList_0100QLowEnergyCharacteristicData sipExportedTypes_QtBluetooth[59]

extern sipMappedTypeDef sipTypeDef_QtBluetooth_QList_0100QLowEnergyCharacteristicData;

#define sipType_QList_0101QLowEnergyService sipExportedTypes_QtBluetooth[62]

extern sipMappedTypeDef sipTypeDef_QtBluetooth_QList_0101QLowEnergyService;

#define sipType_QList_0100QLowEnergyCharacteristic sipExportedTypes_QtBluetooth[58]

extern sipMappedTypeDef sipTypeDef_QtBluetooth_QList_0100QLowEnergyCharacteristic;

#define sipType_QList_0100QLowEnergyDescriptorData sipExportedTypes_QtBluetooth[61]

extern sipMappedTypeDef sipTypeDef_QtBluetooth_QList_0100QLowEnergyDescriptorData;

#define sipType_QList_0100QLowEnergyDescriptor sipExportedTypes_QtBluetooth[60]

extern sipMappedTypeDef sipTypeDef_QtBluetooth_QList_0100QLowEnergyDescriptor;

#define sipType_QList_0100QLowEnergyAdvertisingParameters_AddressInfo sipExportedTypes_QtBluetooth[57]

extern sipMappedTypeDef sipTypeDef_QtBluetooth_QList_0100QLowEnergyAdvertisingParameters_AddressInfo;

#define sipType_QList_0100QBluetoothServiceInfo sipExportedTypes_QtBluetooth[55]

extern sipMappedTypeDef sipTypeDef_QtBluetooth_QList_0100QBluetoothServiceInfo;

#define sipType_QList_0100QBluetoothAddress sipExportedTypes_QtBluetooth[52]

extern sipMappedTypeDef sipTypeDef_QtBluetooth_QList_0100QBluetoothAddress;

#define sipType_QList_0100QBluetoothHostInfo sipExportedTypes_QtBluetooth[54]

extern sipMappedTypeDef sipTypeDef_QtBluetooth_QList_0100QBluetoothHostInfo;

#define sipType_QMultiHash_0100QBluetoothUuid_0100QByteArray sipExportedTypes_QtBluetooth[88]

extern sipMappedTypeDef sipTypeDef_QtBluetooth_QMultiHash_0100QBluetoothUuid_0100QByteArray;

#define sipType_QMultiHash_1600_0100QByteArray sipExportedTypes_QtBluetooth[89]

extern sipMappedTypeDef sipTypeDef_QtBluetooth_QMultiHash_1600_0100QByteArray;

#define sipType_QList_0100QBluetoothUuid sipExportedTypes_QtBluetooth[56]

extern sipMappedTypeDef sipTypeDef_QtBluetooth_QList_0100QBluetoothUuid;

#define sipType_QList_0100QBluetoothDeviceInfo sipExportedTypes_QtBluetooth[53]

extern sipMappedTypeDef sipTypeDef_QtBluetooth_QList_0100QBluetoothDeviceInfo;

#define sipType_QFlags_0100QLowEnergyService_ServiceType sipExportedTypes_QtBluetooth[51]

extern sipMappedTypeDef sipTypeDef_QtBluetooth_QFlags_0100QLowEnergyService_ServiceType;

#define sipType_QFlags_0100QLowEnergyCharacteristic_PropertyType sipExportedTypes_QtBluetooth[50]

extern sipMappedTypeDef sipTypeDef_QtBluetooth_QFlags_0100QLowEnergyCharacteristic_PropertyType;

#define sipType_QFlags_0100QBluetoothDeviceInfo_ServiceClass sipExportedTypes_QtBluetooth[49]

extern sipMappedTypeDef sipTypeDef_QtBluetooth_QFlags_0100QBluetoothDeviceInfo_ServiceClass;

#define sipType_QFlags_0100QBluetoothDeviceInfo_Field sipExportedTypes_QtBluetooth[48]

extern sipMappedTypeDef sipTypeDef_QtBluetooth_QFlags_0100QBluetoothDeviceInfo_Field;

#define sipType_QFlags_0100QBluetoothDeviceInfo_CoreConfiguration sipExportedTypes_QtBluetooth[47]

extern sipMappedTypeDef sipTypeDef_QtBluetooth_QFlags_0100QBluetoothDeviceInfo_CoreConfiguration;

#define sipType_QFlags_0100QBluetoothDeviceDiscoveryAgent_DiscoveryMethod sipExportedTypes_QtBluetooth[46]

extern sipMappedTypeDef sipTypeDef_QtBluetooth_QFlags_0100QBluetoothDeviceDiscoveryAgent_DiscoveryMethod;

#define sipType_QFlags_0100QBluetooth_Security sipExportedTypes_QtBluetooth[45]

extern sipMappedTypeDef sipTypeDef_QtBluetooth_QFlags_0100QBluetooth_Security;

#define sipType_QFlags_0100QBluetooth_AttAccessConstraint sipExportedTypes_QtBluetooth[44]

extern sipMappedTypeDef sipTypeDef_QtBluetooth_QFlags_0100QBluetooth_AttAccessConstraint;

#define sipType_QBluetoothServiceInfo_Sequence sipExportedTypes_QtBluetooth[35]

extern sipMappedTypeDef sipTypeDef_QtBluetooth_QBluetoothServiceInfo_Sequence;

#define sipType_quint128 sipExportedTypes_QtBluetooth[90]

extern sipMappedTypeDef sipTypeDef_QtBluetooth_quint128;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtBluetooth;
extern sipExportedModuleDef sipModuleAPI_QtBluetooth;
extern sipTypeDef *sipExportedTypes_QtBluetooth[];

#define sipType_QObject sipImportedTypes_QtBluetooth_QtCore[9].it_td

#define sipType_QIODeviceBase sipImportedTypes_QtBluetooth_QtCore[6].it_td

#define sipType_QIODevice sipImportedTypes_QtBluetooth_QtCore[5].it_td

#define sipType_QByteArray sipImportedTypes_QtBluetooth_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtBluetooth_QtCore[3].it_td

#define sipType_QTimerEvent sipImportedTypes_QtBluetooth_QtCore[12].it_td

#define sipType_QChildEvent sipImportedTypes_QtBluetooth_QtCore[1].it_td

#define sipType_QDataStream sipImportedTypes_QtBluetooth_QtCore[2].it_td

#define sipType_QMetaMethod sipImportedTypes_QtBluetooth_QtCore[8].it_td

#define sipType_QSysInfo_Endian sipImportedTypes_QtBluetooth_QtCore[11].it_td

#define sipType_QUuid sipImportedTypes_QtBluetooth_QtCore[13].it_td

#define sipType_QVariant sipImportedTypes_QtBluetooth_QtCore[14].it_td

#define sipType_QFlags_0100QIODeviceBase_OpenModeFlag sipImportedTypes_QtBluetooth_QtCore[4].it_td

#define sipType_QList_1600 sipImportedTypes_QtBluetooth_QtCore[7].it_td

#define sipType_QString sipImportedTypes_QtBluetooth_QtCore[10].it_td
extern sipImportedTypeDef sipImportedTypes_QtBluetooth_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtBluetooth_QtCore[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtBluetooth_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtBluetooth_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtBluetooth_qt_metacast;

#endif
